@@ -1,22 +1,28 @@
 /*
  * ark -- archiver for the KDE project
  *
- * Copyright (C) 2009 Harald Hvaal <haraldhv atatatat stud.ntnu.no>
+ * Copyright (C) 2009 Harald Hvaal <haraldhv@stud.ntnu.no>
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ * 1. Redistributions of source code must retain the above copyright
+ *    notice, this list of conditions and the following disclaimer.
+ * 2. Redistributions in binary form must reproduce the above copyright
+ *    notice, this list of conditions and the following disclaimer in the
+ *    documentation and/or other materials provided with the distribution.
  *
+ * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
+ * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
+ * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
+ * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
+ * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES ( INCLUDING, BUT
+ * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
+ * DATA, OR PROFITS; OR BUSINESS INTERRUPTION ) HOWEVER CAUSED AND ON ANY
+ * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+ * ( INCLUDING NEGLIGENCE OR OTHERWISE ) ARISING IN ANY WAY OUT OF THE USE OF
+ * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
 #include "cliinterface.h"
@@ -36,8 +42,8 @@
 
 namespace Kerfuffle
 {
-CliInterface::CliInterface(const QString& filename, QObject *parent)
-        : ReadWriteArchiveInterface(filename, parent),
+CliInterface::CliInterface(QObject *parent, const QVariantList & args)
+        : ReadWriteArchiveInterface(parent, args),
         m_process(0)
 {
     //because this interface uses the event loop
@@ -63,10 +69,9 @@ CliInterface::~CliInterface()
 bool CliInterface::list()
 {
     cacheParameterList();
-    m_mode = List;
+    m_operationMode = List;
 
-    bool ret = findProgramAndCreateProcess(m_param.value(ListProgram).toString());
-    if (!ret) {
+    if (!findProgramAndCreateProcess(m_param.value(ListProgram).toString())) {
         failOperation();
         return false;
     }
@@ -81,13 +86,12 @@ bool CliInterface::list()
 
 bool CliInterface::copyFiles(const QList<QVariant> & files, const QString & destinationDirectory, ExtractionOptions options)
 {
-    kDebug(1601) ;
+    kDebug() ;
     cacheParameterList();
 
-    m_mode = Copy;
+    m_operationMode = Copy;
 
-    bool ret = findProgramAndCreateProcess(m_param.value(ExtractProgram).toString());
-    if (!ret) {
+    if (!findProgramAndCreateProcess(m_param.value(ExtractProgram).toString())) {
         failOperation();
         return false;
     }
@@ -98,7 +102,7 @@ bool CliInterface::copyFiles(const QList<QVariant> & files, const QString & dest
     //now replace the various elements in the list
     for (int i = 0; i < args.size(); ++i) {
         QString argument = args.at(i);
-        kDebug(1601) << "Processing argument " << argument;
+        kDebug() << "Processing argument " << argument;
 
         if (argument == "$Archive") {
             args[i] = filename();
@@ -136,7 +140,7 @@ bool CliInterface::copyFiles(const QList<QVariant> & files, const QString & dest
             //if we get a hint about this being a password protected archive, ask about
             //the password in advance.
             if (options.value("PasswordProtectedHint").toBool() && password().isEmpty()) {
-                kDebug(1601) << "Password hint enabled, querying user";
+                kDebug() << "Password hint enabled, querying user";
 
                 Kerfuffle::PasswordNeededQuery query(filename());
                 userQuery(&query);
@@ -180,7 +184,7 @@ bool CliInterface::copyFiles(const QList<QVariant> & files, const QString & dest
             QString rootNode;
             if (options.contains("RootNode")) {
                 rootNode = options.value("RootNode").toString();
-                kDebug(1601) << "Set root node " << rootNode;
+                kDebug() << "Set root node " << rootNode;
             }
 
             if (!rootNode.isEmpty()) {
@@ -211,7 +215,7 @@ bool CliInterface::copyFiles(const QList<QVariant> & files, const QString & dest
         }
     }
 
-    kDebug(1601) << "Setting current dir to " << destinationDirectory;
+    kDebug() << "Setting current dir to " << destinationDirectory;
     QDir::setCurrent(destinationDirectory);
 
     executeProcess(m_program, args);
@@ -223,18 +227,18 @@ bool CliInterface::addFiles(const QStringList & files, const CompressionOptions&
 {
     cacheParameterList();
 
-    m_mode = Add;
+    m_operationMode = Add;
 
-    bool ret = findProgramAndCreateProcess(m_param.value(AddProgram).toString());
-    if (!ret) {
+    if (!findProgramAndCreateProcess(m_param.value(AddProgram).toString())) {
         failOperation();
         return false;
     }
 
-    QString globalWorkdir = options.value("GlobalWorkDir").toString();
-    if (!globalWorkdir.isEmpty()) {
-        kDebug(1601) << "GlobalWorkDir is set, changing dir to " << globalWorkdir;
-        QDir::setCurrent(globalWorkdir);
+    const QString globalWorkDir = options.value("GlobalWorkDir").toString();
+    const QDir workDir = globalWorkDir.isEmpty() ? QDir::current() : QDir(globalWorkDir);
+    if (!globalWorkDir.isEmpty()) {
+        kDebug() << "GlobalWorkDir is set, changing dir to " << globalWorkDir;
+        QDir::setCurrent(globalWorkDir);
     }
 
     //start preparing the argument list
@@ -242,8 +246,8 @@ bool CliInterface::addFiles(const QStringList & files, const CompressionOptions&
 
     //now replace the various elements in the list
     for (int i = 0; i < args.size(); ++i) {
-        QString argument = args.at(i);
-        kDebug(1601) << "Processing argument " << argument;
+        const QString argument = args.at(i);
+        kDebug() << "Processing argument " << argument;
 
         if (argument == "$Archive") {
             args[i] = filename();
@@ -252,8 +256,12 @@ bool CliInterface::addFiles(const QStringList & files, const CompressionOptions&
         if (argument == "$Files") {
             args.removeAt(i);
             for (int j = 0; j < files.count(); ++j) {
-
-                QString relativeName = QDir::current().relativeFilePath(files.at(j));
+                // #191821: workDir must be used instead of QDir::current()
+                //          so that symlinks aren't resolved automatically
+                // TODO: this kind of call should be moved upwards in the
+                //       class hierarchy to avoid code duplication
+                const QString relativeName =
+                    workDir.relativeFilePath(files.at(j));
 
                 args.insert(i + j, relativeName);
                 ++i;
@@ -270,10 +278,9 @@ bool CliInterface::addFiles(const QStringList & files, const CompressionOptions&
 bool CliInterface::deleteFiles(const QList<QVariant> & files)
 {
     cacheParameterList();
-    m_mode = Delete;
+    m_operationMode = Delete;
 
-    bool ret = findProgramAndCreateProcess(m_param.value(DeleteProgram).toString());
-    if (!ret) {
+    if (!findProgramAndCreateProcess(m_param.value(DeleteProgram).toString())) {
         failOperation();
         return false;
     }
@@ -284,7 +291,7 @@ bool CliInterface::deleteFiles(const QList<QVariant> & files)
     //now replace the various elements in the list
     for (int i = 0; i < args.size(); ++i) {
         QString argument = args.at(i);
-        kDebug(1601) << "Processing argument " << argument;
+        kDebug() << "Processing argument " << argument;
 
         if (argument == "$Archive") {
             args[i] = filename();
@@ -312,7 +319,7 @@ bool CliInterface::deleteFiles(const QList<QVariant> & files)
 
 bool CliInterface::createProcess()
 {
-    kDebug(1601);
+    kDebug();
 
     if (m_process) {
         delete m_process;
@@ -335,7 +342,7 @@ bool CliInterface::createProcess()
 
 bool CliInterface::executeProcess(const QString& path, const QStringList & args)
 {
-    kDebug(1601) << "Executing " << path << args;
+    kDebug() << "Executing " << path << args;
     Q_ASSERT(!path.isEmpty());
 
     m_process->setProgram(path, args);
@@ -353,17 +360,17 @@ void CliInterface::started()
 
 void CliInterface::processFinished(int exitCode, QProcess::ExitStatus exitStatus)
 {
-    Q_UNUSED(exitCode);
-    Q_UNUSED(exitStatus);
+    Q_UNUSED(exitCode)
+    Q_UNUSED(exitStatus)
 
-    kDebug(1601);
+    kDebug();
 
     //if the m_process pointer is gone, then there is nothing to worry
     //about here
     if (!m_process)
         return;
 
-    if (m_mode == Delete) {
+    if (m_operationMode == Delete) {
         foreach(const QVariant& v, m_removedFiles) {
             entryRemoved(v.toString());
         }
@@ -374,7 +381,7 @@ void CliInterface::processFinished(int exitCode, QProcess::ExitStatus exitStatus
 
     progress(1.0);
 
-    if (m_mode == Add) {
+    if (m_operationMode == Add) {
         list();
         return;
     }
@@ -385,7 +392,7 @@ void CliInterface::processFinished(int exitCode, QProcess::ExitStatus exitStatus
 
 void CliInterface::failOperation()
 {
-    kDebug(1601);
+    kDebug();
 
     if (m_process)
         m_process->terminate();
@@ -467,7 +474,7 @@ void CliInterface::readStdout(bool handleAll)
 
 void CliInterface::handleLine(const QString& line)
 {
-    if ((m_mode == Copy || m_mode == Add) && m_param.contains(CaptureProgress) && m_param.value(CaptureProgress).toBool()) {
+    if ((m_operationMode == Copy || m_operationMode == Add) && m_param.contains(CaptureProgress) && m_param.value(CaptureProgress).toBool()) {
         //read the percentage
         int pos = line.indexOf('%');
         if (pos != -1 && pos > 1) {
@@ -477,9 +484,9 @@ void CliInterface::handleLine(const QString& line)
         }
     }
 
-    if (m_mode == Copy) {
+    if (m_operationMode == Copy) {
         if (checkForErrorMessage(line, WrongPasswordPatterns)) {
-            kDebug(1601) << "Wrong password!";
+            kDebug() << "Wrong password!";
             error(i18n("Incorrect password."));
             setPassword(QString());
             failOperation();
@@ -487,7 +494,7 @@ void CliInterface::handleLine(const QString& line)
         }
 
         if (checkForErrorMessage(line, ExtractionFailedPatterns)) {
-            kDebug(1601) << "Error in extraction!!";
+            kDebug() << "Error in extraction!!";
             error(i18n("Extraction failed because of an unexpected error."));
             failOperation();
             return;
@@ -497,7 +504,25 @@ void CliInterface::handleLine(const QString& line)
             return;
     }
 
-    if (m_mode == List) {
+    if (m_operationMode == List) {
+        if (checkForErrorMessage(line, WrongPasswordPatterns)) {
+            kDebug() << "Wrong password!";
+            error(i18n("Incorrect password."));
+            setPassword(QString());
+            failOperation();
+            return;
+        }
+
+        if (checkForErrorMessage(line, ExtractionFailedPatterns)) {
+            kDebug() << "Error in extraction!!";
+            error(i18n("Extraction failed because of an unexpected error."));
+            failOperation();
+            return;
+        }
+
+        if (handleFileExistsMessage(line))
+            return;
+
         readListLine(line);
         return;
     }
@@ -506,15 +531,14 @@ void CliInterface::handleLine(const QString& line)
 bool CliInterface::findProgramAndCreateProcess(const QString& program)
 {
     m_program = KStandardDirs::findExe(program);
-    bool ret = !m_program.isEmpty();
-    if (!ret) {
+
+    if (m_program.isEmpty()) {
         error(i18n("Failed to locate program '%1' in PATH.", program));
         return false;
     }
 
-    ret = createProcess();
-    if (!ret) {
-        error(i18n("Found program '%1', but failed to initalise the process.", program));
+    if (!createProcess()) {
+        error(i18n("Found program '%1', but failed to initialize the process.", program));
         return false;
     }
 
@@ -527,7 +551,7 @@ bool CliInterface::checkForFileExistsMessage(const QString& line)
         m_existsPattern.setPattern(m_param.value(FileExistsExpression).toString());
     }
     if (m_existsPattern.indexIn(line) != -1) {
-        kDebug(1601) << "Detected file existing!! Filename " << m_existsPattern.cap(1);
+        kDebug() << "Detected file existing!! Filename " << m_existsPattern.cap(1);
         return true;
     }
 
@@ -539,18 +563,18 @@ bool CliInterface::handleFileExistsMessage(const QString& line)
     if (!checkForFileExistsMessage(line))
         return false;
 
-    QString filename = m_existsPattern.cap(1);
+    const QString filename = m_existsPattern.cap(1);
 
     Kerfuffle::OverwriteQuery query(QDir::current().path() + '/' + filename);
     query.setNoRenameMode(true);
     userQuery(&query);
-    kDebug(1601) << "Waiting response";
+    kDebug() << "Waiting response";
     query.waitForResponse();
 
-    kDebug(1601) << "Finished response";
+    kDebug() << "Finished response";
 
     QString responseToProcess;
-    QStringList choices = m_param.value(FileExistsInput).toStringList();
+    const QStringList choices = m_param.value(FileExistsInput).toStringList();
 
     if (query.responseOverwrite())
         responseToProcess = choices.at(0);
@@ -567,7 +591,7 @@ bool CliInterface::handleFileExistsMessage(const QString& line)
 
     responseToProcess += '\n';
 
-    kDebug(1601) << "Writing " << responseToProcess;
+    kDebug() << "Writing " << responseToProcess;
 
     m_process->write(responseToProcess.toLocal8Bit());
 
@@ -628,7 +652,7 @@ bool CliInterface::doResume()
 void CliInterface::substituteListVariables(QStringList& params)
 {
     for (int i = 0; i < params.size(); ++i) {
-        QString parameter = params.at(i);
+        const QString parameter = params.at(i);
 
         if (parameter == "$Archive") {
             params[i] = filename();
