@@ -1,25 +1,31 @@
 /*
  * ark -- archiver for the KDE project
  *
- * Copyright (C) 2009 Harald Hvaal <haraldhv atatatat stud.ntnu.no>
+ * Copyright (C) 2009 Harald Hvaal <haraldhv@stud.ntnu.no>
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ * 1. Redistributions of source code must retain the above copyright
+ *    notice, this list of conditions and the following disclaimer.
+ * 2. Redistributions in binary form must reproduce the above copyright
+ *    notice, this list of conditions and the following disclaimer in the
+ *    documentation and/or other materials provided with the distribution.
  *
+ * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
+ * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
+ * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
+ * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
+ * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES ( INCLUDING, BUT
+ * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
+ * DATA, OR PROFITS; OR BUSINESS INTERRUPTION ) HOWEVER CAUSED AND ON ANY
+ * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+ * ( INCLUDING NEGLIGENCE OR OTHERWISE ) ARISING IN ANY WAY OUT OF THE USE OF
+ * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
-#ifndef _CLIINTERFACE_H_
-#define _CLIINTERFACE_H_
+#ifndef CLIINTERFACE_H
+#define CLIINTERFACE_H
 
 #include "archiveinterface.h"
 #include "kerfuffle_export.h"
@@ -30,8 +36,6 @@ class KProcess;
 
 namespace Kerfuffle
 {
-enum CliInterfaceExtractOptions {
-};
 
 enum CliInterfaceParameters {
 
@@ -217,9 +221,9 @@ public:
     enum OperationMode  {
         List, Copy, Add, Delete
     };
-    OperationMode m_mode;
+    OperationMode m_operationMode;
 
-    explicit CliInterface(const QString& filename, QObject *parent = 0);
+    explicit CliInterface(QObject *parent, const QVariantList & args);
     virtual ~CliInterface();
 
     virtual bool list();
@@ -232,7 +236,6 @@ public:
 
 private:
     bool findProgramAndCreateProcess(const QString& program);
-    void substituteCopyVariables(QStringList& params, const QList<QVariant> & files, const QString & destinationDirectory, ExtractionOptions options);
     void substituteListVariables(QStringList& params);
 
     bool createProcess();
@@ -265,4 +268,4 @@ private slots:
 };
 }
 
-#endif /* _CLIINTERFACE_H_ */
+#endif /* CLIINTERFACE_H */
