@@ -38,6 +38,8 @@
 #include <KIconLoader>
 #include <KIO/NetAccess>
 
+using namespace Kerfuffle;
+
 class ArchiveDirNode;
 
 //used to speed up the loading of large archives
@@ -285,7 +287,7 @@ QVariant ArchiveModel::headerData(int section, Qt::Orientation, int role) const
 {
     if (role == Qt::DisplayRole) {
         if (section >= m_showColumns.size()) {
-            kDebug(1601) << "WEIRD: showColumns.size = " << m_showColumns.size()
+            kDebug() << "WEIRD: showColumns.size = " << m_showColumns.size()
             << " and section = " << section;
             return QVariant();
         }
@@ -462,7 +464,7 @@ QStringList ArchiveModel::mimeTypes() const
 
 QMimeData * ArchiveModel::mimeData(const QModelIndexList & indexes) const
 {
-    kDebug(1601) ;
+    kDebug() ;
     //prepare the fallback kio_slave filenames
     QStringList files;
     bool noFallback = false;
@@ -488,7 +490,7 @@ QMimeData * ArchiveModel::mimeData(const QModelIndexList & indexes) const
         //to limit only one index per row
         if (index.column() != 0) continue;
 
-        QString file = archiveName + static_cast<ArchiveNode*>(index.internalPointer())->entry()[ FileName ].toString();
+        const QString file = archiveName + static_cast<ArchiveNode*>(index.internalPointer())->entry()[ FileName ].toString();
         files << file;
     }
 
@@ -508,10 +510,10 @@ QMimeData * ArchiveModel::mimeData(const QModelIndexList & indexes) const
 
 bool ArchiveModel::dropMimeData(const QMimeData * data, Qt::DropAction action, int row, int column, const QModelIndex & parent)
 {
-    Q_UNUSED(action);
-    Q_UNUSED(row);
-    Q_UNUSED(column);
-    Q_UNUSED(parent);
+    Q_UNUSED(action)
+    Q_UNUSED(row)
+    Q_UNUSED(column)
+    Q_UNUSED(parent)
 
     if (!data->hasUrls())
         return false;
@@ -535,7 +537,7 @@ bool ArchiveModel::dropMimeData(const QMimeData * data, Qt::DropAction action, i
         }
     }
 
-    kDebug(1601) << "Dropped onto " << path;
+    kDebug() << "Dropped onto " << path;
 
 #endif
 
@@ -627,10 +629,9 @@ QModelIndex ArchiveModel::indexForNode(ArchiveNode *node)
 
 void ArchiveModel::slotEntryRemoved(const QString & path)
 {
-    // TODO: Do something
-    kDebug(1601) << "Removed node at path " << path;
- 
-    QString entryFileName(cleanFileName(path));
+    kDebug() << "Removed node at path " << path;
+
+    const QString entryFileName(cleanFileName(path));
     if (entryFileName.isEmpty()) {
         return;
     }
@@ -647,8 +648,9 @@ void ArchiveModel::slotEntryRemoved(const QString & path)
         delete parent->entries().takeAt(entry->row());
 
         endRemoveRows();
-    } else
-        kDebug(1601) << "Did not find the removed node";
+    } else {
+        kDebug() << "Did not find the removed node";
+    }
 }
 
 void ArchiveModel::slotUserQuery(Query *query)
@@ -673,7 +675,7 @@ void ArchiveModel::slotNewEntry(const ArchiveEntry& entry)
 void ArchiveModel::newEntry(const ArchiveEntry& receivedEntry, InsertBehaviour behaviour)
 {
     if (receivedEntry[FileName].toString().isEmpty()) {
-        kDebug(1601) << "Weird, received empty entry (no filename) - skipping";
+        kDebug() << "Weird, received empty entry (no filename) - skipping";
         return;
     }
 
@@ -707,7 +709,7 @@ void ArchiveModel::newEntry(const ArchiveEntry& receivedEntry, InsertBehaviour b
         m_showColumns << toInsert;
         endInsertColumns();
 
-        kDebug(1601) << "Show columns detected: " << m_showColumns;
+        kDebug() << "Show columns detected: " << m_showColumns;
 
     }
 
@@ -725,7 +727,7 @@ void ArchiveModel::newEntry(const ArchiveEntry& receivedEntry, InsertBehaviour b
     if (m_rootNode) {
         ArchiveNode *existing = m_rootNode->findByPath(entry[ FileName ].toString().split('/'));
         if (existing) {
-            kDebug(1601) << "Refreshing entry for" << entry[FileName].toString();
+            kDebug() << "Refreshing entry for" << entry[FileName].toString();
             //TODO: benchmark whether it's a bad idea to reset the entry here.
             existing->setEntry(entry);
             return;
@@ -752,7 +754,7 @@ void ArchiveModel::newEntry(const ArchiveEntry& receivedEntry, InsertBehaviour b
 
 void ArchiveModel::slotLoadingFinished(KJob *job)
 {
-    //kDebug (1601) << entry;
+    //kDebug() << entry;
     foreach(const ArchiveEntry &entry, m_newArchiveEntries) {
         newEntry(entry, DoNotNotifyViews);
     }
@@ -772,6 +774,11 @@ void ArchiveModel::insertNode(ArchiveNode *node, InsertBehaviour behaviour)
     if (behaviour == NotifyViews) endInsertRows();
 }
 
+Kerfuffle::Archive* ArchiveModel::archive() const
+{
+    return m_archive;
+}
+
 KJob* ArchiveModel::setArchive(Kerfuffle::Archive *archive)
 {
     delete m_archive;
@@ -857,7 +864,7 @@ DeleteJob* ArchiveModel::deleteFiles(const QList<QVariant> & files)
 
 void ArchiveModel::slotCleanupEmptyDirs()
 {
-    kDebug(1601);
+    kDebug();
     QList<QPersistentModelIndex> queue;
     QList<QPersistentModelIndex> nodesToDelete;
 
@@ -870,7 +877,7 @@ void ArchiveModel::slotCleanupEmptyDirs()
     while (!queue.isEmpty()) {
         QPersistentModelIndex node = queue.takeFirst();
         ArchiveEntry entry = entryForIndex(node);
-        //kDebug(1601) << "Trying " << entry[FileName].toString();
+        //kDebug() << "Trying " << entry[FileName].toString();
 
         if (!hasChildren(node)) {
             if (!entry.contains(InternalID)) {
@@ -889,7 +896,7 @@ void ArchiveModel::slotCleanupEmptyDirs()
         beginRemoveRows(parent(node), rawNode->row(), rawNode->row());
         delete rawNode->parent()->entries().takeAt(rawNode->row());
         endRemoveRows();
-        //kDebug(1601) << "Removed entry " << entry[FileName].toString();
+        //kDebug() << "Removed entry " << entry[FileName].toString();
     }
 }
 
