@@ -38,35 +38,6 @@
 #include <QHBoxLayout>
 #include <QFrame>
 #include <QLabel>
-#include <QDrag>
-#include <QMimeData>
-#include <QMouseEvent>
-
-class DraggableIcon : public QLabel
-{
-public:
-    KUrl m_url;
-
-    DraggableIcon(QWidget *parent, KUrl url)
-            : QLabel(parent), m_url(url) {
-
-    }
-
-    void mousePressEvent(QMouseEvent *event) {
-        kDebug(1601) ;
-        if (event->button() == Qt::LeftButton) {
-            QDrag *drag = new QDrag(this);
-            QMimeData *mimeData = new QMimeData;
-
-            mimeData->setUrls(QList<QUrl>() << m_url);
-
-            drag->setMimeData(mimeData);
-
-            drag->exec();
-        }
-    }
-};
-
 
 ArkViewer::ArkViewer(QWidget * parent)
         : KDialog(parent), m_part(0)
@@ -107,7 +78,17 @@ void ArkViewer::view(const QString& filename, QWidget *parent)
     if (viewer.isNull()) {
         KMessageBox::sorry(parent, i18n("The internal viewer cannot preview this file."));
     } else if (viewer->hasServiceType("KParts/ReadOnlyPart")) {
-        ArkViewer(parent).viewInInternalViewer(filename);
+        ArkViewer *internalViewer = new ArkViewer(parent);
+
+        internalViewer->hide();
+
+        if (!internalViewer->viewInInternalViewer(filename)) {
+            KMessageBox::sorry(parent, i18n("The internal viewer cannot preview this file."));
+            delete internalViewer;
+            return;
+        }
+
+        internalViewer->show();
     } else { // Try to open it in an external application
         KUrl fileUrl(filename);
         KRun::runUrl(fileUrl, KMimeType::findByUrl(fileUrl, 0, true)->name(), parent);
@@ -147,7 +128,7 @@ bool ArkViewer::viewInInternalViewer(const QString& filename)
     QFrame *header = new QFrame(m_widget);
     QHBoxLayout *headerLayout = new QHBoxLayout(header);
 
-    QLabel *iconLabel = new DraggableIcon(header, u);
+    QLabel *iconLabel = new QLabel(header);
     headerLayout->addWidget(iconLabel);
     iconLabel->setPixmap(KIconLoader::global()->loadMimeTypeIcon(mimetype->iconName(), KIconLoader::Desktop));
     iconLabel->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Minimum);
@@ -161,32 +142,31 @@ bool ArkViewer::viewInInternalViewer(const QString& filename)
 
     header->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Maximum);
 
-
-    //m_part = KParts::ComponentFactory::createPartInstanceFromQuery<KParts::ReadOnlyPart>( mimetype->name(), QString(), m_widget, this );
     m_part = KMimeTypeTrader::self()->createPartInstanceFromQuery<KParts::ReadOnlyPart>(mimetype->name(),
              m_widget,
              this);
 
-    if (m_part) {
-        if (m_part->browserExtension())
-            connect(m_part->browserExtension(),
-                    SIGNAL(openUrlRequestDelayed(KUrl, KParts::OpenUrlArguments, KParts::BrowserArguments)),
-                    SLOT(slotOpenUrlRequestDelayed(KUrl, KParts::OpenUrlArguments, KParts::BrowserArguments)));
-
-        m_part->openUrl(filename);
-        exec();
-        return true;
-    } else {
+    if (!m_part) {
         return false;
     }
+
+    if (m_part->browserExtension()) {
+        connect(m_part->browserExtension(),
+                SIGNAL(openUrlRequestDelayed(KUrl, KParts::OpenUrlArguments, KParts::BrowserArguments)),
+                SLOT(slotOpenUrlRequestDelayed(KUrl, KParts::OpenUrlArguments, KParts::BrowserArguments)));
+    }
+
+    m_part->openUrl(filename);
+
+    return true;
 }
 
 void ArkViewer::slotOpenUrlRequestDelayed(const KUrl& url, const KParts::OpenUrlArguments& arguments, const KParts::BrowserArguments& browserArguments)
 {
-    kDebug(1601) << "Opening URL: " << url;
+    kDebug() << "Opening URL: " << url;
 
-    Q_UNUSED(arguments);
-    Q_UNUSED(browserArguments);
+    Q_UNUSED(arguments)
+    Q_UNUSED(browserArguments)
 
     KRun *runner = new KRun(url, 0, 0, false);
     runner->setRunExecutables(false);
