@@ -3,6 +3,7 @@
  *
  * Copyright (C) 2007 Henrique Pinto <henrique.pinto@kdemail.net>
  * Copyright (C) 2008-2009 Harald Hvaal <haraldhv@stud.ntnu.no>
+ * Copyright (C) 2009 Raphael Kubo da Costa <kubito@gmail.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -24,6 +25,7 @@
 #include "archiveview.h"
 #include "infopanel.h"
 #include "arkviewer.h"
+#include "kerfuffle/archive.h"
 #include "kerfuffle/extractiondialog.h"
 #include "kerfuffle/jobs.h"
 #include "kerfuffle/settings.h"
@@ -40,11 +42,11 @@
 #include <KIcon>
 #include <KTempDir>
 #include <KMessageBox>
-#include <KVBox>
 #include <KRun>
 #include <KFileDialog>
 #include <KConfigGroup>
 #include <KStandardDirs>
+#include <KToggleAction>
 #include <KIO/NetAccess>
 
 #include <QCursor>
@@ -60,32 +62,43 @@
 #include <QHeaderView>
 #include <QPointer>
 
+using namespace Kerfuffle;
+
 typedef KParts::GenericFactory<Ark::Part> Factory;
-K_EXPORT_COMPONENT_FACTORY(libarkpart, Factory)
+K_EXPORT_COMPONENT_FACTORY(arkpart, Factory)
 
 namespace Ark
 {
 
 Part::Part(QWidget *parentWidget, QObject *parent, const QStringList& args)
-        : KParts::ReadWritePart(parent), m_model(new ArchiveModel(this)), m_previewDir(0), m_busy(false),
-        m_jobTracker(NULL)
+        : KParts::ReadWritePart(parent),
+          m_model(new ArchiveModel(this)),
+          m_splitter(0),
+          m_previewDir(0),
+          m_busy(false),
+          m_jobTracker(0)
 {
-    Q_UNUSED(args);
+    Q_UNUSED(args)
     setComponentData(Factory::componentData());
-    setXMLFile("ark_part.rc");
 
-    KVBox *mainWidget = new KVBox(parentWidget);
-    setWidget(mainWidget);
+    m_splitter = new QSplitter(Qt::Horizontal, parentWidget);
+    setWidget(m_splitter);
 
-    QSplitter *splitter = new QSplitter(Qt::Horizontal, mainWidget);
-    m_view = new ArchiveView(mainWidget);
-    m_infoPanel = new InfoPanel(m_model, mainWidget);
-    splitter->addWidget(m_view);
-    splitter->addWidget(m_infoPanel);
+    m_view = new ArchiveView(m_splitter);
+    m_infoPanel = new InfoPanel(m_model, m_splitter);
+
+    QList<int> splitterSizes = ArkSettings::splitterSizes();
+    if (splitterSizes.isEmpty()) {
+        splitterSizes.append(200);
+        splitterSizes.append(100);
+    }
+    m_splitter->setSizes(splitterSizes);
 
     setupView();
     setupActions();
 
+    connect(m_splitter, SIGNAL(splitterMoved(int, int)), SLOT(slotUpdateSplitterSizes()));
+
     connect(m_model, SIGNAL(loadingStarted()),
             this, SLOT(slotLoadingStarted()));
     connect(m_model, SIGNAL(loadingFinished(KJob *)),
@@ -107,6 +120,7 @@ Part::Part(QWidget *parentWidget, QObject *parent, const QStringList& args)
     new DndExtractAdaptor(this);
     QDBusConnection::sessionBus().registerObject("/DndExtract", this);
 
+    setXMLFile("ark_part.rc");
 }
 
 Part::~Part()
@@ -134,7 +148,7 @@ void Part::registerJob(KJob* job)
 
 void Part::extractSelectedFilesTo(QString localPath)
 {
-    kDebug(1601) << "Extract to " << localPath;
+    kDebug() << "Extract to " << localPath;
     if (!m_model) return;
 
     if (m_view->selectionModel()->selectedRows().count() != 1) {
@@ -143,7 +157,7 @@ void Part::extractSelectedFilesTo(QString localPath)
     if (m_view->selectionModel()->selectedRows().count() != 1) return;
 
     QVariant internalRoot;
-    kDebug(1601) << "valid " << m_view->currentIndex().parent().isValid();
+    kDebug() << "valid " << m_view->currentIndex().parent().isValid();
     if (m_view->currentIndex().parent().isValid())
         internalRoot = m_model->entryForIndex(m_view->currentIndex().parent()).value(InternalID);
 
@@ -159,7 +173,7 @@ void Part::extractSelectedFilesTo(QString localPath)
     QList<QVariant> files = selectedFilesWithChildren();
     if (files.isEmpty()) return;
 
-    kDebug(1601) << "selected files are " << files;
+    kDebug() << "selected files are " << files;
     Kerfuffle::ExtractionOptions options;
     options["PreservePaths"] = true;
     if (!internalRoot.isNull()) options["RootNode"] = internalRoot;
@@ -194,6 +208,14 @@ void Part::setupView()
 
 void Part::setupActions()
 {
+    KToggleAction *showInfoPanelAction = new KToggleAction(i18n("Show information panel"), this);
+    actionCollection()->addAction("show-infopanel", showInfoPanelAction);
+    showInfoPanelAction->setChecked(m_splitter->sizes().at(1) > 0);
+    connect(showInfoPanelAction, SIGNAL(triggered(bool)),
+            this, SLOT(slotToggleInfoPanel(bool)));
+
+    m_saveAsAction = KStandardAction::saveAs(this, SLOT(slotSaveAs()), actionCollection());
+
     m_previewAction = actionCollection()->addAction("preview");
     m_previewAction->setText(i18nc("to preview a file inside an archive", "Pre&view"));
     m_previewAction->setIcon(KIcon("document-preview-archive"));
@@ -226,6 +248,7 @@ void Part::setupActions()
     m_deleteFilesAction = actionCollection()->addAction("delete");
     m_deleteFilesAction->setIcon(KIcon("archive-remove"));
     m_deleteFilesAction->setText(i18n("De&lete"));
+    m_deleteFilesAction->setShortcut(Qt::Key_Delete);
     m_deleteFilesAction->setStatusTip(i18n("Click to delete the selected files"));
     connect(m_deleteFilesAction, SIGNAL(triggered(bool)),
             this, SLOT(slotDeleteFiles()));
@@ -273,9 +296,9 @@ void Part::slotQuickExtractFiles(QAction *triggeredAction)
 {
     kDebug() << "Extract to " << triggeredAction->data().toString();
 
-    QString userDestination = triggeredAction->data().toString();
+    const QString userDestination = triggeredAction->data().toString();
     QString finalDestinationDirectory;
-    QString detectedSubfolder = detectSubfolder();
+    const QString detectedSubfolder = detectSubfolder();
 
     if (!isSingleFolderArchive()) {
         finalDestinationDirectory = userDestination +
@@ -338,9 +361,9 @@ bool Part::openFile()
         QHash<QString, QString> mimeTypes;
 
         if (arguments().metaData()["createNewArchive"] == "true")
-            mimeTypeList = supportedWriteMimeTypes();
+            mimeTypeList = Kerfuffle::supportedWriteMimeTypes();
         else
-            mimeTypeList = supportedMimeTypes();
+            mimeTypeList = Kerfuffle::supportedMimeTypes();
 
         foreach(const QString& mime, mimeTypeList) {
             KMimeType::Ptr mimePtr(KMimeType::mimeType(mime));
@@ -389,14 +412,9 @@ bool Part::saveFile()
     return true;
 }
 
-QStringList Part::supportedMimeTypes() const
+bool Part::isBusy() const
 {
-    return Kerfuffle::supportedMimeTypes();
-}
-
-QStringList Part::supportedWriteMimeTypes() const
-{
-    return Kerfuffle::supportedWriteMimeTypes();
+    return m_busy;
 }
 
 void Part::slotLoadingStarted()
@@ -405,7 +423,7 @@ void Part::slotLoadingStarted()
 
 void Part::slotLoadingFinished(KJob *job)
 {
-    kDebug(1601);
+    kDebug();
 
     if (job->error())
         if (arguments().metaData()["createNewArchive"] != "true")
@@ -422,7 +440,7 @@ void Part::slotLoadingFinished(KJob *job)
 
 void Part::setReadyGui()
 {
-    kDebug(1601);
+    kDebug();
     QApplication::restoreOverrideCursor();
     m_busy = false;
     m_view->setEnabled(true);
@@ -431,7 +449,7 @@ void Part::setReadyGui()
 
 void Part::setBusyGui()
 {
-    kDebug(1601);
+    kDebug();
     QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
     m_busy = true;
     m_view->setEnabled(false);
@@ -440,7 +458,7 @@ void Part::setBusyGui()
 
 void Part::setFileNameFromArchive()
 {
-    QString prettyName = url().fileName();
+    const QString prettyName = url().fileName();
 
     m_infoPanel->setPrettyFileName(prettyName);
     m_infoPanel->updateWithDefaults();
@@ -458,8 +476,13 @@ void Part::slotPreview(const QModelIndex & index)
     if (!m_previewDir) {
         m_previewDir = new KTempDir();
     }
-    if (!isPreviewable(index)) return;
+
+    if (!isPreviewable(index)) {
+        return;
+    }
+
     const ArchiveEntry& entry =  m_model->entryForIndex(index);
+
     if (!entry.isEmpty()) {
         ExtractJob *job = m_model->extractFile(entry[ InternalID ], m_previewDir->name());
         registerJob(job);
@@ -474,8 +497,8 @@ void Part::slotPreviewExtracted(KJob *job)
     if (!job->error()) {
         //ArkViewer viewer( widget() );
         const ArchiveEntry& entry =  m_model->entryForIndex(m_view->selectionModel()->currentIndex());
-        QString name = entry[ FileName ].toString().split('/', QString::SkipEmptyParts).last();
-        QString fullName = m_previewDir->name() + '/' + name;
+        const QString name = entry[ FileName ].toString().split('/', QString::SkipEmptyParts).last();
+        const QString fullName = m_previewDir->name() + '/' + name;
         ArkViewer::view(fullName, widget());
     } else {
         KMessageBox::error(widget(), job->errorString());
@@ -506,7 +529,7 @@ QString Part::detectSubfolder()
 
 void Part::slotExtractFiles()
 {
-    kDebug(1601) ;
+    kDebug() ;
     if (!m_model) return;
 
     QPointer<Kerfuffle::ExtractionDialog> dialog = new Kerfuffle::ExtractionDialog();
@@ -537,7 +560,7 @@ void Part::slotExtractFiles()
             files = selectedFilesWithChildren();
         }
 
-        kDebug(1601) << "Selected " << files;
+        kDebug() << "Selected " << files;
 
         Kerfuffle::ExtractionOptions options;
 
@@ -602,7 +625,7 @@ QList<QVariant> Part::selectedFiles()
 
 void Part::slotExtractionDone(KJob* job)
 {
-    kDebug(1601);
+    kDebug();
     if (job->error()) {
         KMessageBox::error(widget(), job->errorString());
     } else {
@@ -617,7 +640,7 @@ void Part::slotExtractionDone(KJob* job)
 
 void Part::adjustColumns()
 {
-    kDebug(1601);
+    kDebug();
 
     m_view->header()->setResizeMode(0, QHeaderView::ResizeToContents);
 }
@@ -628,8 +651,8 @@ void Part::slotAddFiles(const QStringList& filesToAdd, const QString& path)
         return;
     }
 
-    kDebug(1601) << "Adding " << filesToAdd << " to " << path;
-    kDebug(1601) << "Warning, for now the path argument is not implemented";
+    kDebug() << "Adding " << filesToAdd << " to " << path;
+    kDebug() << "Warning, for now the path argument is not implemented";
 
     QStringList cleanFilesToAdd(filesToAdd);
     for (int i = 0; i < cleanFilesToAdd.size(); ++i) {
@@ -645,7 +668,7 @@ void Part::slotAddFiles(const QStringList& filesToAdd, const QString& path)
     if (firstPath.right(1) == "/") firstPath.chop(1);
     firstPath = QFileInfo(firstPath).dir().absolutePath();
 
-    kDebug(1601) << "Detected relative path to be " << firstPath;
+    kDebug() << "Detected relative path to be " << firstPath;
     options["GlobalWorkDir"] = firstPath;
 
     AddJob *job = m_model->addFiles(cleanFilesToAdd, options);
@@ -659,7 +682,7 @@ void Part::slotAddFiles(const QStringList& filesToAdd, const QString& path)
 
 void Part::slotAddFiles()
 {
-    kDebug(1601) ;
+    kDebug() ;
     const QStringList filesToAdd = KFileDialog::getOpenFileNames(KUrl("kfiledialog:///ArkAddFiles"), QString(), widget(), i18n("Add Files"));
 
     slotAddFiles(filesToAdd);
@@ -667,8 +690,8 @@ void Part::slotAddFiles()
 
 void Part::slotAddDir()
 {
-    kDebug(1601) ;
-    QString dirToAdd = KFileDialog::getExistingDirectory(KUrl("kfiledialog:///ArkAddFiles"), widget(), i18n("Add Folder"));
+    kDebug() ;
+    const QString dirToAdd = KFileDialog::getExistingDirectory(KUrl("kfiledialog:///ArkAddFiles"), widget(), i18n("Add Folder"));
 
     if (!dirToAdd.isEmpty()) {
         slotAddFiles(QStringList() << dirToAdd);
@@ -677,7 +700,7 @@ void Part::slotAddDir()
 
 void Part::slotAddFilesDone(KJob* job)
 {
-    kDebug(1601) ;
+    kDebug() ;
     if (job->error()) {
         KMessageBox::error(widget(), job->errorString());
     }
@@ -685,7 +708,7 @@ void Part::slotAddFilesDone(KJob* job)
 
 void Part::slotDeleteFilesDone(KJob* job)
 {
-    kDebug(1601) ;
+    kDebug() ;
     if (job->error()) {
         KMessageBox::error(widget(), job->errorString());
     }
@@ -693,9 +716,9 @@ void Part::slotDeleteFilesDone(KJob* job)
 
 void Part::slotDeleteFiles()
 {
-    kDebug(1601) ;
+    kDebug() ;
 
-    int reallyDelete =  KMessageBox::questionYesNo(NULL, i18n("Deleting these files is not undoable. Are you sure you want to do this?"), i18n("Delete files") , KGuiItem(i18n("Delete files")), KGuiItem(i18n("Cancel")));
+    const int reallyDelete = KMessageBox::questionYesNo(NULL, i18n("Deleting these files is not undoable. Are you sure you want to do this?"), i18n("Delete files") , KGuiItem(i18n("Delete files")), KGuiItem(i18n("Cancel")));
 
     if (reallyDelete == KMessageBox::No)
         return;
@@ -707,4 +730,64 @@ void Part::slotDeleteFiles()
     job->start();
 }
 
+void Part::slotToggleInfoPanel(bool visible)
+{
+    QList<int> splitterSizes;
+
+    if (visible) {
+        splitterSizes = ArkSettings::splitterSizesWithBothWidgets();
+    } else {
+        splitterSizes = m_splitter->sizes();
+        ArkSettings::setSplitterSizesWithBothWidgets(splitterSizes);
+        splitterSizes[1] = 0;
+    }
+
+    m_splitter->setSizes(splitterSizes);
+    slotUpdateSplitterSizes();
+}
+
+void Part::slotUpdateSplitterSizes()
+{
+    ArkSettings::setSplitterSizes(m_splitter->sizes());
+    ArkSettings::self()->writeConfig();
+}
+
+void Part::slotSaveAs()
+{
+    KUrl saveUrl = KFileDialog::getSaveUrl(KUrl("kfiledialog:///ArkSaveAs/" + url().fileName()), QString(), widget());
+
+    if ((saveUrl.isValid()) && (!saveUrl.isEmpty())) {
+        if (KIO::NetAccess::exists(saveUrl, KIO::NetAccess::DestinationSide, widget())) {
+            int overwrite = KMessageBox::warningContinueCancel(widget(),
+                                                               i18n("A file named <b>%1</b> already exists. Are you sure you want to overwrite it?", saveUrl.fileName()),
+                                                               QString(),
+                                                               KGuiItem(i18n("Overwrite")));
+
+            if (overwrite != KMessageBox::Continue) {
+                return;
+            }
+        }
+
+        KUrl srcUrl = KUrl::fromPath(localFilePath());
+
+        if (!QFile::exists(localFilePath())) {
+            if (url().isLocalFile()) {
+                KMessageBox::error(widget(),
+                                   i18n("The file <b>%1</b> cannot be copied to the specified location. The archive does not exist anymore.", localFilePath()));
+
+                return;
+            } else {
+                srcUrl = url();
+            }
+        }
+
+        KIO::Job *copyJob = KIO::file_copy(srcUrl, saveUrl, -1, KIO::Overwrite);
+
+        if (!KIO::NetAccess::synchronousRun(copyJob, widget())) {
+            KMessageBox::error(widget(),
+                               i18n("The archive could not be saved as <b>%1</b>. Try to save it in another location.", saveUrl.pathOrUrl()));
+        }
+    }
+}
+
 } // namespace Ark
