@@ -3,6 +3,7 @@
  *
  * Copyright (C) 2007 Henrique Pinto <henrique.pinto@kdemail.net>
  * Copyright (C) 2008-2009 Harald Hvaal <haraldhv@stud.ntnu.no>
+ * Copyright (C) 2009 Raphael Kubo da Costa <kubito@gmail.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -30,6 +31,7 @@
 class ArchiveModel;
 class InfoPanel;
 
+class QSplitter;
 class QTreeView;
 class QAction;
 class KAction;
@@ -54,12 +56,7 @@ public:
     virtual bool openFile();
     virtual bool saveFile();
 
-    QStringList supportedMimeTypes() const;
-    QStringList supportedWriteMimeTypes() const;
-
-    bool isBusy() const {
-        return m_busy;
-    }
+    bool isBusy() const;
 
 public slots:
     void extractSelectedFilesTo(QString localPath);
@@ -80,6 +77,9 @@ private slots:
     void slotAddFilesDone(KJob*);
     void slotDeleteFiles();
     void slotDeleteFilesDone(KJob*);
+    void slotUpdateSplitterSizes();
+    void slotToggleInfoPanel(bool);
+    void slotSaveAs();
     void updateActions();
     void selectionChanged();
     void adjustColumns();
@@ -103,12 +103,14 @@ private:
 
     ArchiveModel         *m_model;
     QTreeView            *m_view;
-    QAction              *m_previewAction;
+    KAction              *m_previewAction;
     KAction              *m_extractFilesAction;
-    QAction              *m_addFilesAction;
-    QAction              *m_addDirAction;
-    QAction              *m_deleteFilesAction;
+    KAction              *m_addFilesAction;
+    KAction              *m_addDirAction;
+    KAction              *m_deleteFilesAction;
+    KAction              *m_saveAsAction;
     InfoPanel            *m_infoPanel;
+    QSplitter            *m_splitter;
     KTempDir             *m_previewDir;
     bool                  m_busy;
     QString               m_destinationDirectory;
