@@ -46,6 +46,9 @@ private:
     QStandardItemModel *dbusAppsModel;
     QStandardItemModel *argumentsModel;
     DBusFunctionModel *dbusFunctionModel;
+    ProfileModel *profileModel;
+    RemoteButtonModel *remoteButtonModel;
+    
     enum  {
         START =0,
         SELECT_BUTTON =1,
@@ -69,33 +72,27 @@ private:
 protected:
     virtual void initializePage(int id);
 
-public slots:
-    virtual void slotModeSelected();
-    virtual void updateButtonStates();
-    virtual void updateButton(const QString &remote, const QString &button);
-    virtual void updateButtons();
-    virtual void updateDBusApplications();
-    virtual void updateDBusFunctions(QModelIndex);
-    virtual void updateProfiles();
-    virtual void updateProfileFunctions();
-    virtual void updateArguments();
-    virtual void updateOptions();
+private slots:
+    void slotModeSelected();
+    void updateButtonStates();
+    void updateButton(const QString &remote, const QString &button);
+    void updateButtons();
+    void updateDBusApplications();
+    void updateDBusFunctions(QModelIndex);
+    void updateProfiles();
+    void updateProfileFunctions();
+    void updateArguments();
+    void updateOptions();
+    void tryAction();
+    
 
 public:
-//    Arguments theArguments;
     bool isUnique;
-
     static const QStringList getFunctions(const QString app, const QString obj);
-    void updateArgument(QTreeWidgetItem *theItem);
     IRAction * getAction();
-
-//    QMap<QListWidgetItem *, QString> profileMap;
-//    QMap<QTreeWidgetItem *, QString> profileFunctionMap;
-
     AddAction(QWidget *parent, const char *name, const Mode &mode);
     ~AddAction();
 
-
     virtual int nextId () const;
 };
 
