@@ -23,6 +23,8 @@
 #include <QtDBus/QtDBus>
 #include <QtGui/QPrinter>
 #include <QtGui/QPrintDialog>
+#include <QVBoxLayout>
+#include <QWidget>
 
 #include <KToggleAction>
 #include <KStandardAction>
@@ -30,6 +32,7 @@
 #include <KIcon>
 #include <KFindDialog>
 #include <KFind>
+#include <KMenuBar>
 #include <KShortcut>
 #include <KEncodingFileDialog>
 #include <kio/netaccess.h>
@@ -39,6 +42,8 @@
 #include <KAction>
 #include <KLocale>
 #include <KDebug>
+#include <KRecentFilesAction>
+#include <KToolBar>
 
 #include "selectsecretkey.h"
 #include "kgpgmd5widget.h"
@@ -46,25 +51,41 @@
 #include "kgpglibrary.h"
 #include "keyservers.h"
 #include "sourceselect.h"
-#include "kgpgview.h"
+#include "kgpgtextedit.h"
 #include "kgpg.h"
 #include "kgpg_interface.h"
 #include "kgpgtextinterface.h"
 
+class KgpgView : public QWidget {
+public:
+	KgpgView(QWidget *parent, KgpgTextEdit *editor, KToolBar *toolbar);
+};
 
-KgpgEditor::KgpgEditor(QWidget *parent, KGpgItemModel *model, Qt::WFlags f, KShortcut gohome, bool mainwindow)
-          : KXmlGuiWindow(parent, f), view(new KgpgView(this, model))
+KgpgView::KgpgView(QWidget *parent, KgpgTextEdit *editor, KToolBar *toolbar)
+	: QWidget(parent)
 {
-    m_ismainwindow = mainwindow;
-    m_godefaultkey = gohome;
-    m_find = 0;
-    m_model = model;
+	QVBoxLayout *vb = new QVBoxLayout(this);
+	vb->setSpacing(3);
+	vb->addWidget(editor);
+	vb->addWidget(toolbar);
 
+	setAcceptDrops(true);
+}
+
+KgpgEditor::KgpgEditor(KeysManager *parent, KGpgItemModel *model, Qt::WFlags f)
+          : KXmlGuiWindow(0, f),
+	  m_editor(new KgpgTextEdit(this, model)),
+	  m_recentfiles(NULL),
+	  m_find(0),
+	  m_model(model),
+	  m_parent(parent)
+{
     // call inits to invoke all other construction parts
     initActions();
 
-    connect(view, SIGNAL(resetEncoding(bool)), this, SLOT(slotResetEncoding(bool)));
-    setCentralWidget(view);
+    connect(m_editor, SIGNAL(resetEncoding(bool)), SLOT(slotResetEncoding(bool)));
+    KgpgView *kb = new KgpgView(this, m_editor, toolBar("gpgToolBar"));
+    setCentralWidget(kb);
     setCaption(i18n("Untitled"), false);
     m_editredo->setEnabled(false);
     m_editundo->setEnabled(false);
@@ -75,19 +96,19 @@ KgpgEditor::KgpgEditor(QWidget *parent, KGpgItemModel *model, Qt::WFlags f, KSho
 
     setObjectName("editor");
     slotSetFont(KGpgSettings::font());
-    setupGUI((ToolBar | Keys | StatusBar | Save | Create), "kgpg.rc");
+    setupGUI((ToolBar | Keys | StatusBar | Save | Create), "kgpgeditor.rc");
     setAutoSaveSettings("Editor", true);
 
-    connect(view, SIGNAL(textChanged()), this, SLOT(modified()));
-    connect(view, SIGNAL(newText()), this, SLOT(newText()));
-    connect(view->editor, SIGNAL(undoAvailable(bool)), this, SLOT(slotUndoAvailable(bool)));
-    connect(view->editor, SIGNAL(redoAvailable(bool)), this, SLOT(slotRedoAvailable(bool)));
-    connect(view->editor, SIGNAL(copyAvailable(bool)), this, SLOT(slotCopyAvailable(bool)));
+    connect(m_editor, SIGNAL(textChanged()), SLOT(modified()));
+    connect(m_editor, SIGNAL(newText()), SLOT(newText()));
+    connect(m_editor, SIGNAL(undoAvailable(bool)), SLOT(slotUndoAvailable(bool)));
+    connect(m_editor, SIGNAL(redoAvailable(bool)), SLOT(slotRedoAvailable(bool)));
+    connect(m_editor, SIGNAL(copyAvailable(bool)), SLOT(slotCopyAvailable(bool)));
 }
 
 KgpgEditor::~KgpgEditor()
 {
-    delete view;
+    m_recentfiles->saveEntries( KConfigGroup(KGlobal::config(), "Recent Files" ) );
 }
 
 void KgpgEditor::openDocumentFile(const KUrl& url, const QString &encoding)
@@ -100,12 +121,13 @@ void KgpgEditor::openDocumentFile(const KUrl& url, const QString &encoding)
         {
             QTextStream t(&qfile);
             t.setCodec(encoding.toAscii());
-            view->editor->setPlainText(t.readAll());
+            m_editor->setPlainText(t.readAll());
             qfile.close();
             m_docname = url;
             m_textchanged = false;
             m_emptytext = false;
             setCaption(url.fileName(), false);
+	    m_recentfiles->addUrl(url);
         }
         KIO::NetAccess::removeTempFile(tempopenfile);
     }
@@ -113,16 +135,17 @@ void KgpgEditor::openDocumentFile(const KUrl& url, const QString &encoding)
 
 void KgpgEditor::openEncryptedDocumentFile(const KUrl& url)
 {
-    view->editor->slotDroppedFile(url);
+    m_editor->slotDroppedFile(url);
 }
 
 void KgpgEditor::slotSetFont(QFont myFont)
 {
-    view->editor->setFont(myFont);
+    m_editor->setFont(myFont);
 }
 
 void KgpgEditor::closeWindow()
 {
+    m_recentfiles->saveEntries( KConfigGroup(KGlobal::config(), "Recent Files" ) );
     close();
 }
 
@@ -153,7 +176,13 @@ void KgpgEditor::initActions()
     m_editcopy = KStandardAction::copy(this, SLOT(slotEditCopy()), actionCollection());
     m_editcut  = KStandardAction::cut(this, SLOT(slotEditCut()), actionCollection());
 
-    QAction *action = actionCollection()->addAction("file_encrypt");
+    m_recentfiles = KStandardAction::openRecent(this, SLOT(openDocumentFile(const KUrl&)), this);
+    menuBar()->addAction(m_recentfiles);
+
+    m_recentfiles->loadEntries( KConfigGroup(KGlobal::config(), "Recent Files" ) );
+    m_recentfiles->setMaxItems(KGpgSettings::recentFiles());
+
+    KAction *action = actionCollection()->addAction("file_encrypt");
     action->setIcon(KIcon("document-encrypt"));
     action->setText(i18n("&Encrypt File..."));
     connect(action, SIGNAL(triggered(bool)), SLOT(slotFilePreEnc()));
@@ -167,6 +196,7 @@ void KgpgEditor::initActions()
     connect(action, SIGNAL(triggered(bool)), SLOT(slotKeyManager()));
     action = actionCollection()->addAction("sign_generate");
     action->setText(i18n("&Generate Signature..."));
+    action->setIcon(KIcon("document-sign-key"));
     connect(action, SIGNAL(triggered(bool) ), SLOT(slotPreSignFile()));
     action = actionCollection()->addAction("sign_verify");
     action->setText(i18n("&Verify Signature..."));
@@ -178,13 +208,30 @@ void KgpgEditor::initActions()
     m_encodingaction = actionCollection()->add<KToggleAction>("charsets");
     m_encodingaction->setText(i18n("&Unicode (utf-8) Encoding"));
     connect(m_encodingaction, SIGNAL(triggered(bool) ), SLOT(slotSetCharset()));
+
+    actionCollection()->addAction(m_recentfiles->objectName(), m_recentfiles);
+
+    action = actionCollection()->addAction("text_encrypt");
+    action->setIcon(KIcon("document-encrypt"));
+    action->setText(i18n("En&crypt"));
+    connect(action, SIGNAL(triggered(bool)), m_editor, SLOT(slotEncode()));
+
+    action = actionCollection()->addAction("text_decrypt");
+    action->setIcon(KIcon("document-decrypt"));
+    action->setText(i18n("&Decrypt"));
+    connect(action, SIGNAL(triggered(bool)), m_editor, SLOT(slotDecode()));
+
+    action = actionCollection()->addAction("text_sign_verify");
+    action->setIcon(KIcon("document-sign-key"));
+    action->setText(i18n("S&ign/Verify"));
+    connect(action, SIGNAL(triggered(bool)), m_editor, SLOT(slotSignVerify()));
 }
 
 bool KgpgEditor::queryClose()
 {
 	bool b = saveBeforeClear();
 	if (b) {
-		view->editor->clear();
+		m_editor->clear();
 		newText();
 	}
 	return b;
@@ -219,7 +266,7 @@ void KgpgEditor::slotFileNew()
 {
     if (saveBeforeClear())
     {
-        view->editor->clear();
+        m_editor->clear();
         newText();
     }
 }
@@ -263,7 +310,7 @@ bool KgpgEditor::slotFileSave()
 
         QTextStream t(&f);
         t.setCodec(cod);
-        t << view->editor->toPlainText();
+        t << m_editor->toPlainText();
         f.close();
     }
     else
@@ -272,7 +319,7 @@ bool KgpgEditor::slotFileSave()
         tmpfile.open();
         QTextStream stream(&tmpfile);
         stream.setCodec(cod);
-        stream << view->editor->toPlainText();
+        stream << m_editor->toPlainText();
 
         if(!KIO::NetAccess::upload(tmpfile.fileName(), m_docname, this))
         {
@@ -329,47 +376,47 @@ bool KgpgEditor::slotFileSaveAs()
 void KgpgEditor::slotFilePrint()
 {
     QPrinter prt;
-    QPrintDialog printDialog(&prt, this);
-    if (printDialog.exec())
-    {
+    QPointer<QPrintDialog> printDialog = new QPrintDialog(&prt, this);
+    if (printDialog->exec() == QDialog::Accepted) {
         int width = prt.width();
         int height = prt.height();
         QPainter painter(&prt);
-        painter.drawText(0, 0, width, height, Qt::AlignLeft | Qt::AlignTop | Qt::TextDontClip, view->editor->toPlainText());
+        painter.drawText(0, 0, width, height, Qt::AlignLeft | Qt::AlignTop | Qt::TextDontClip, m_editor->toPlainText());
     }
+    delete printDialog;
 }
 
 void KgpgEditor::slotFind()
 {
-    KFindDialog fd(this);
+	QPointer<KFindDialog> fd = new KFindDialog(this);
 
-    if (m_find)
-    {
-        fd.setOptions(m_find->options());
-        fd.setPattern(m_find->pattern());
-    }
+	if (m_find) {
+		fd->setOptions(m_find->options());
+		fd->setPattern(m_find->pattern());
+	}
 
-    if (fd.exec() != QDialog::Accepted)
-        return;
+	if (fd->exec() != QDialog::Accepted) {
+		delete fd;
+		return;
+	}
 
-    if (!m_find)
-    {
-        m_find = new KFind(fd.pattern(), fd.options(), this);
-        if (m_find->options() & KFind::FromCursor)
-            m_find->setData(view->editor->toPlainText(), view->editor->textCursor().selectionStart());
-        else
-            m_find->setData(view->editor->toPlainText());
-        connect(m_find, SIGNAL(highlight(QString, int, int)), view, SLOT(slotHighlightText(QString, int, int)));
-        connect(m_find, SIGNAL(findNext()), this, SLOT(slotFindText()));
-    }
-    else
-    {
-        m_find->setPattern(fd.pattern());
-        m_find->setOptions(fd.options());
-        m_find->resetCounts();
-    }
+	if (!m_find) {
+		m_find = new KFind(fd->pattern(), fd->options(), this);
 
-    slotFindText();
+		if (m_find->options() & KFind::FromCursor)
+			m_find->setData(m_editor->toPlainText(), m_editor->textCursor().selectionStart());
+		else
+			m_find->setData(m_editor->toPlainText());
+		connect(m_find, SIGNAL(highlight(QString, int, int)), m_editor, SLOT(slotHighlightText(QString, int, int)));
+		connect(m_find, SIGNAL(findNext()), this, SLOT(slotFindText()));
+	} else {
+		m_find->setPattern(fd->pattern());
+		m_find->setOptions(fd->options());
+		m_find->resetCounts();
+	}
+
+	slotFindText();
+	delete fd;
 }
 
 void KgpgEditor::slotFindNext()
@@ -411,7 +458,7 @@ void KgpgEditor::slotFindText()
         {
             if (m_find->shouldRestart(true, false))
             {
-                m_find->setData(view->editor->toPlainText());
+                m_find->setData(m_editor->toPlainText());
                 slotFindText();
             }
             else
@@ -438,7 +485,7 @@ void KgpgEditor::slotFilePreDec()
     QString oldname = url.fileName();
     QString newname;
 
-    if (oldname.endsWith(".gpg") || oldname.endsWith(".asc") || oldname.endsWith(".pgp"))
+    if (oldname.endsWith(QLatin1String(".gpg")) || oldname.endsWith(QLatin1String(".asc")) || oldname.endsWith(QLatin1String(".pgp")))
         oldname.truncate(oldname.length() - 4);
     else
         oldname.append(".clear");
@@ -474,19 +521,20 @@ void KgpgEditor::slotFilePreDec()
     if (!newname.isEmpty())
     {
         QFile fgpg(newname);
-        if (fgpg.exists())
-        {
-            KIO::RenameDialog over(0, i18n("File Already Exists"), KUrl(), KUrl::fromPath(newname), KIO::M_OVERWRITE);
-            if (over.exec() == QDialog::Rejected)
-            {
-                return;
-            }
-            newname = over.newDestUrl().path();
+        if (fgpg.exists()) {
+		QPointer<KIO::RenameDialog> over = new KIO::RenameDialog(this, i18n("File Already Exists"), KUrl(), KUrl::fromPath(newname), KIO::M_OVERWRITE);
+
+		if (over->exec() != QDialog::Accepted) {
+			delete over;
+			return;
+		}
+		newname = over->newDestUrl().path();
+		delete over;
         }
 
         KgpgLibrary *lib = new KgpgLibrary(this);
-        lib->slotFileDec(url, KUrl(newname), m_customdecrypt);
         connect(lib, SIGNAL(importOver(KgpgLibrary *, QStringList)), SIGNAL(slotRefreshImported(KgpgLibrary *, QStringList)));
+        lib->slotFileDec(url, KUrl(newname), m_customdecrypt);
     }
     else
         openEncryptedDocumentFile(url);
@@ -515,49 +563,49 @@ void KgpgEditor::slotFileClose()
 
 void KgpgEditor::slotundo()
 {
-    view->editor->undo();
+    m_editor->undo();
 }
 
 void KgpgEditor::slotredo()
 {
-    view->editor->redo();
+    m_editor->redo();
 }
 
 void KgpgEditor::slotEditCut()
 {
-    view->editor->cut();
+    m_editor->cut();
 }
 
 void KgpgEditor::slotEditCopy()
 {
-    view->editor->copy();
+    m_editor->copy();
 }
 
 void KgpgEditor::slotEditPaste()
 {
-    view->editor->paste();
+    m_editor->paste();
 }
 
 void KgpgEditor::slotSelectAll()
 {
-    view->editor->selectAll();
+    m_editor->selectAll();
 }
 
 void KgpgEditor::slotSetCharset()
 {
     if (!m_encodingaction->isChecked())
-        view->editor->setPlainText(QString::fromUtf8(view->editor->toPlainText().toAscii()));
+        m_editor->setPlainText(QString::fromUtf8(m_editor->toPlainText().toAscii()));
     else
     {
         if (checkEncoding(QTextCodec::codecForLocale()))
             return;
-        view->editor->setPlainText(view->editor->toPlainText().toUtf8());
+        m_editor->setPlainText(m_editor->toPlainText().toUtf8());
     }
 }
 
 bool KgpgEditor::checkEncoding(QTextCodec *codec)
 {
-    return codec->canEncode(view->editor->toPlainText());
+    return codec->canEncode(m_editor->toPlainText());
 }
 
 void KgpgEditor::slotResetEncoding(bool enc)
@@ -579,11 +627,10 @@ void KgpgEditor::slotSignFile(const KUrl &url)
     if (!url.isEmpty())
     {
         QString signKeyID;
-        KgpgSelectSecretKey *opts = new KgpgSelectSecretKey(this, m_model, false);
-        if (opts->exec() == QDialog::Accepted)
+        QPointer<KgpgSelectSecretKey> opts = new KgpgSelectSecretKey(this, m_model, false);
+        if (opts->exec() == QDialog::Accepted) {
             signKeyID = opts->getKeyID();
-        else
-        {
+        } else {
             delete opts;
             return;
         }
@@ -592,9 +639,9 @@ void KgpgEditor::slotSignFile(const KUrl &url)
 
         QStringList Options;
         if (KGpgSettings::asciiArmor())
-            Options << QString::fromLocal8Bit("--armor");
+            Options << "--armor";
         if (KGpgSettings::pgpCompatibility())
-            Options << QString::fromLocal8Bit("--pgp6");
+            Options << "--pgp6";
         Options << "--detach-sign";
 
         KGpgTextInterface *interface = new KGpgTextInterface();
@@ -619,7 +666,7 @@ void KgpgEditor::slotVerifyFile(const KUrl &url)
     if (!url.isEmpty())
     {
         QString sigfile;
-        if (!url.fileName().endsWith(".sig"))
+	if (!url.fileName().endsWith(QLatin1String(".sig")))
         {
             sigfile = url.path() + ".sig";
             QFile fsig(sigfile);
@@ -646,7 +693,7 @@ void KgpgEditor::slotCheckMd5()
     KUrl url = KFileDialog::getOpenUrl(KUrl(), i18n("*|All Files"), this, i18n("Open File to Verify"));
     if (!url.isEmpty())
     {
-        Md5Widget *mdwidget = new Md5Widget(this, url);
+        QPointer<Md5Widget> mdwidget = new Md5Widget(this, url);
         mdwidget->exec();
         delete mdwidget;
     }
@@ -671,14 +718,14 @@ void KgpgEditor::modified()
 {
 	QString capt = m_docname.fileName();
 	if (m_emptytext) {
-		m_textchanged = !view->editor->toPlainText().isEmpty();
+		m_textchanged = !m_editor->toPlainText().isEmpty();
 		if (capt.isEmpty())
 			capt = i18n("Untitled");
 	} else if (!m_textchanged) {
 		m_textchanged = true;
 	}
 	setCaption(capt, m_textchanged);
-	view->editor->document()->setModified(m_textchanged);
+	m_editor->document()->setModified(m_textchanged);
 }
 
 void KgpgEditor::slotUndoAvailable(const bool &v)
