@@ -56,7 +56,7 @@ QString KgpgInterface::checkForUtf8(QString txt)
 
 	// if (!strchr (txt.toAscii(), 0xc3) || (txt.find("\\x")!=-1)) {
 	for (int idx = 0; (idx = txt.indexOf( "\\x", idx )) >= 0 ; ++idx) {
-		char str[2] = "x";
+		char str[2] = { 'x', '\0'};
 		str[0] = (char) QString(txt.mid(idx + 2, 2)).toShort(0, 16);
 		txt.replace(idx, 4, str);
 	}
@@ -117,7 +117,7 @@ QString KgpgInterface::getGpgProcessHome(const QString &binary)
 
 	QString line;
 	while (process.readln(line) != -1) {
-		if (line.startsWith("Home: ")) {
+		if (line.startsWith(QLatin1String("Home: "))) {
 			line.remove(0, 6);
 			return line;
 		}
@@ -170,9 +170,9 @@ QStringList KgpgInterface::getGpgGroupNames(const QString &configfile)
 		QTextStream t(&qfile);
 		while (!t.atEnd()) {
 			QString result(t.readLine().simplified());
-			if (result.startsWith("group ")) {
+			if (result.startsWith(QLatin1String("group "))) {
 				result.remove(0, 6);
-				groups.append(result.section("=", 0, 0).simplified());
+				groups.append(result.section('=', 0, 0).simplified());
 			}
 		}
 		qfile.close();
@@ -188,14 +188,14 @@ QStringList KgpgInterface::getGpgGroupSetting(const QString &name, const QString
 		while (!t.atEnd()) {
 			QString result(t.readLine().simplified());
 
-			if (result.startsWith("group ")) {
+			if (result.startsWith(QLatin1String("group "))) {
 				kDebug(2100) << "Found 1 group";
 				result.remove(0, 6);
 				if (result.simplified().startsWith(name)) {
 					kDebug(2100) << "Found group: " << name;
 					result = result.section('=', 1);
 					result = result.section('#', 0, 0);
-					return result.split(' ');
+					return result.split(' ', QString::SkipEmptyParts);
 				}
 			}
 		}
@@ -218,7 +218,7 @@ void KgpgInterface::setGpgGroupSetting(const QString &name, const QStringList &v
 			QString result(t.readLine());
 			QString result2(result.simplified());
 
-			if (result2.startsWith("group ")) {
+			if (result2.startsWith(QLatin1String("group "))) {
 				result2 = result2.remove(0, 6).simplified();
 				if (result2.startsWith(name) && (result2.remove(0, name.length()).simplified().startsWith('='))) {
 					result = QString("group %1=%2").arg(name).arg(values.join(QString(' ')));
@@ -252,7 +252,7 @@ void KgpgInterface::delGpgGroup(const QString &name, const QString &configfile)
 			const QString result(t.readLine());
 			QString result2(result.simplified());
 
-			if (result2.startsWith("group ")) {
+			if (result2.startsWith(QLatin1String("group "))) {
 				result2 = result2.remove(0, 6).simplified();
 				if (result2.startsWith(name) && (result2.remove(0, name.length()).simplified().startsWith('=')))
 					continue;
@@ -282,7 +282,7 @@ QString KgpgInterface::getGpgSetting(const QString &name, const QString &configf
 			QString result(t.readLine().simplified());
 			if (result.startsWith(tmp)) {
 				result = result.mid(tmp.length()).simplified();
-				return result.section(" ", 0, 0);
+				return result.section(' ', 0, 0);
 			}
 		}
 		qfile.close();
@@ -527,15 +527,15 @@ void KgpgInterface::readPublicKeysProcess(GPGProc *p)
 				kmail = fullname;
 
 				if (fullname.contains(')') )
-				kmail = kmail.section(')', 1);
+					kmail = kmail.section(')', 1);
 
 				kmail = kmail.section('<', 1);
 				kmail.truncate(kmail.length() - 1);
 
-				if ( kmail.contains('<') ) // several email addresses in the same key
-				{
-				kmail = kmail.replace('>', ';');
-				kmail.remove('<');
+				if (kmail.contains('<')) {
+					// several email addresses in the same key
+					kmail = kmail.replace('>', ';');
+					kmail.remove('<');
 				}
 			}
 
@@ -581,8 +581,7 @@ void KgpgInterface::readPublicKeysProcess(GPGProc *p)
 			if (lsp.at(10).endsWith('l'))
 				signature.setLocal(true);
 
-			if (lsp.at(0) == "rev")
-				signature.setRevocation(true);
+			signature.setRevocation(lsp.at(0) == "rev");
 
 			if (cycle == "pub")
 				m_publickey.addSign(signature);
@@ -712,7 +711,7 @@ void KgpgInterface::readSecretKeysProcess(GPGProc *p)
 }
 
 KgpgCore::KgpgKeyList
-KgpgInterface::readJoinedKeys(const KgpgKeyTrust &trust, const QStringList &ids)
+KgpgInterface::readJoinedKeys(const KgpgCore::KgpgKeyTrust trust, const QStringList &ids)
 {
 	KgpgKeyList secretkeys = readSecretKeys(ids);
 	KgpgKeyList publickeys = readPublicKeys(true, ids, false);
@@ -722,9 +721,9 @@ KgpgInterface::readJoinedKeys(const KgpgKeyTrust &trust, const QStringList &ids)
 		if (publickeys.at(i).trust() < trust)
 			publickeys.removeAt(i);
 
-	for (i = 0; i < secretkeys.size(); i++) {
+	foreach (const KgpgKey &seckey, secretkeys) {
 		for (j = 0; j < publickeys.size(); j++)
-			if (secretkeys.at(i).fullId() == publickeys.at(j).fullId()) {
+			if (seckey.fullId() == publickeys.at(j).fullId()) {
 				publickeys[j].setSecret(true);
 				break;
 			}
@@ -738,174 +737,6 @@ KgpgInterface::readJoinedKeys(const KgpgKeyTrust &trust, const QStringList &ids)
 	return publickeys;
 }
 
-QString KgpgInterface::getKeys(const QString &attributes, const QStringList &ids)
-{
-	m_keystring.clear();
-
-	GPGProc *gpgProcess = new GPGProc(this);
-	*gpgProcess << "--export" << "--armor" << "--status-fd=1" << "--command-fd=0";
-
-	if (!attributes.isEmpty())
-		*gpgProcess << "--export-options" << attributes;
-
-	*gpgProcess << ids;
-
-	connect(gpgProcess, SIGNAL(readReady(GPGProc *)), SLOT(getKeysProcess(GPGProc *)));
-	gpgProcess->start();
-	gpgProcess->waitForFinished(-1);
-	delete gpgProcess;
-	return m_keystring;
-}
-
-void KgpgInterface::getKeysProcess(GPGProc *gpgProcess)
-{
-	QString line;
-
-	while (gpgProcess->readln(line, true) >= 0) {
-		if (!line.startsWith("gpg:"))
-			m_keystring += line + '\n';
-	}
-}
-
-void KgpgInterface::signKey(const QString &keyid, const QString &signkeyid, const bool local, const int checking, const bool terminal, const QString &uid)
-{
-	m_partialline.clear();
-	m_ispartial = false;
-	log.clear();
-	m_signkey = signkeyid;
-	m_keyid = keyid;
-	m_checking = checking;
-	m_local = local;
-	step = 3;
-
-	if (terminal) {
-		signKeyOpenConsole();
-		return;
-	}
-
-	m_success = 0;
-
-	m_workProcess = new KProcess(this);
-	m_workProcess->setOutputChannelMode(KProcess::OnlyStdoutChannel);
-	*m_workProcess << KGpgSettings::gpgBinaryPath();
-	*m_workProcess << "--no-secmem-warning" << "--no-tty" << "--status-fd=1" << "--command-fd=0";
-
-	*m_workProcess << "-u" << signkeyid;
-	*m_workProcess << "--edit-key" << keyid;
-
-	if (!uid.isEmpty())
-		*m_workProcess << "uid" << uid;
-
-	if (local)
-		*m_workProcess << "lsign";
-	else
-		*m_workProcess << "sign";
-
-	kDebug(2100) << "Signing key" << keyid << "uid" << uid << "with key" << signkeyid;
-	connect(m_workProcess, SIGNAL(readyReadStandardOutput()), this, SLOT(signKeyProcess()));
-	connect(m_workProcess, SIGNAL(finished(int, QProcess::ExitStatus)), this, SLOT(signKeyFin()));
-
-	m_workProcess->start();
-}
-
-void KgpgInterface::signKeyProcess()
-{
-	QString buffer(m_partialline + m_workProcess->readAllStandardOutput());
-
-	while (buffer.contains('\n')) {
-		int pos = buffer.indexOf('\n');
-		QString line(buffer.left(pos));
-		buffer.remove(0, pos + 1);
-
-		if (line.startsWith("[GNUPG:]")) {
-			if (line.contains("USERID_HINT")) {
-				updateIDs(line);
-			} else if (m_success == 3) {
-				// user has aborted the process and don't want to sign the key
-				if (line.contains("GET_"))
-					m_workProcess->write("quit\n");
-				return;
-			} else if (line.contains("ALREADY_SIGNED")) {
-				m_success = 4;
-			} else  if (line.contains("GOOD_PASSPHRASE")) {
-				m_success = 2;
-			} else if (line.contains("sign_uid.expire")) {
-				m_workProcess->write("Never\n");
-			} else if (line.contains("sign_uid.class")) {
-				m_workProcess->write(QString::number(m_checking).toAscii() + '\n');
-			} else if (line.contains("sign_uid.okay")) {
-				m_workProcess->write("Y\n");
-			} else if (line.contains("sign_all.okay")) {
-				m_workProcess->write("Y\n");
-			} else if (line.contains("passphrase.enter")) {
-				QString passdlgmessage;
-				if (step < 3)
-					passdlgmessage = i18np("<p><b>Bad passphrase</b>. You have 1 try left.</p>",
-							"<p><b>Bad passphrase</b>. You have %1 tries left.</p>", step);
-				passdlgmessage += i18n("Enter passphrase for <b>%1</b>", checkForUtf8bis(userIDs));
-
-				if (sendPassphrase(passdlgmessage, m_workProcess, false)) {
-					m_success = 3;
-					m_workProcess->write("quit\n");
-					return;
-				}
-
-				if (step > 1)
-					step--;
-				else
-					step = 3;
-			} else if ((m_success != 1) && line.contains("keyedit.prompt")) {
-				m_workProcess->write("save\n");
-			} else if (line.contains("BAD_PASSPHRASE")) {
-				m_success = 1;
-			} else if (line.contains("GET_")) {
-				// gpg asks for something unusal, turn to konsole mode
-				if (m_success != 1)
-					m_success = 5; // switching to console mode
-				m_workProcess->write("quit\n");
-			}
-		} else {
-			log += line + '\n';
-		}
-	}
-	m_partialline = buffer;
-}
-
-void KgpgInterface::signKeyFin()
-{
-	m_workProcess->deleteLater();
-	if ((m_success != 0) && (m_success != 5)) {
-		// signature successful or bad passphrase or aborted or already signed
-		emit signKeyFinished(m_success, m_keyid, this);
-	} else {
-		KgpgDetailedConsole *q = new KgpgDetailedConsole(0,
-				i18n("<qt>Signing key <b>%1</b> with key <b>%2</b> failed.<br />Do you want to try signing the key in console mode?</qt>", m_keyid, m_signkey),
-				log);
-		if (q->exec() == QDialog::Accepted)
-			signKeyOpenConsole();
-		else
-			emit signKeyFinished(3, m_keyid, this);
-	}
-}
-
-void KgpgInterface::signKeyOpenConsole()
-{
-	KConfigGroup config(KGlobal::config(), "General");
-
-	KProcess process;
-	process << config.readPathEntry("TerminalApplication", "konsole");
-	process << "-e" << KGpgSettings::gpgBinaryPath() << "--no-secmem-warning" << "-u" << m_signkey;
-	process << "--default-cert-level" << QString(m_checking);
-
-	if (!m_local)
-		process << "--sign-key" << m_keyid;
-	else
-		process << "--lsign-key" << m_keyid;
-
-	process.execute();
-	emit signKeyFinished(2, m_keyid, this);
-}
-
 QPixmap KgpgInterface::loadPhoto(const QString &keyid, const QString &uid, const bool block)
 {
 #ifdef Q_OS_WIN32	//krazy:exclude=cpp
@@ -1090,11 +921,11 @@ void KgpgInterface::findSigns(const QString &keyID, const QStringList &ids, cons
 	int tgtuid = uid.toInt();
 
 	while (listproc->readln(line, true) >= 0) {
-		if (line.startsWith("sig:") && (tgtuid == curuid)) {
+		if (line.startsWith(QLatin1String("sig:")) && (tgtuid == curuid)) {
 			if (ids.contains(line.section(':', 4, 4), Qt::CaseInsensitive))
 				*res << signs;
 			signs++;
-		} else if (line.startsWith("uid:")) {
+		} else if (line.startsWith(QLatin1String("uid:"))) {
 			curuid++;
 		}
 	}
