@@ -47,7 +47,7 @@ public:
     static QString checkForUtf8bis(QString txt);
 
     /**
-     * \brief parse GnuPG version string and return version as number
+     * @brief parse GnuPG version string and return version as number
      * @param vstr version string
      * @return -1 if vstr is empty, -2 on parse error, parsed number on success
      *
@@ -56,7 +56,7 @@ public:
      */
     static int gpgVersion(const QString &vstr);
     /**
-     * \brief get the GnuPG version string of the given binary
+     * @brief get the GnuPG version string of the given binary
      * @param binary name or path to GnuPG binary
      * @return version string or empty string on error
      *
@@ -65,7 +65,7 @@ public:
      */
     static QString gpgVersionString(const QString &binary);
     /**
-     * \brief find users GnuPG directory
+     * @brief find users GnuPG directory
      * @param binary name or path to GnuPG binary
      * @return path to directory
      *
@@ -86,7 +86,7 @@ public:
     static void setGpgBoolSetting(const QString &name, const bool enable, const QString &url);
 
     /**
-     * \brief ask the user for a passphrase and send it to the given gpg process
+     * @brief ask the user for a passphrase and send it to the given gpg process
      * @param text text is the message that must be displayed in the MessageBox
      * @param process gnupg process
      * @param isnew if the password is a \e new password that must be confirmed. Default is true
@@ -131,7 +131,7 @@ private:
 /************** extract secret keys **************/
 public slots:
     KgpgCore::KgpgKeyList readSecretKeys(const QStringList &ids = QStringList());
-    KgpgCore::KgpgKeyList readJoinedKeys(const KgpgCore::KgpgKeyTrust &trust, const QStringList &ids = QStringList());
+    KgpgCore::KgpgKeyList readJoinedKeys(const KgpgCore::KgpgKeyTrust trust, const QStringList &ids = QStringList());
 
 private slots:
     void readSecretKeysProcess(GPGProc *p);
@@ -144,68 +144,6 @@ private:
 /*************************************************/
 
 
-/************** get keys as a text **************/
-public slots:
-    QString getKeys(const QString &attributes, const QStringList &ids = QStringList());
-
-private slots:
-    void getKeysProcess(GPGProc *);
-
-private:
-    QString m_keystring;
-
-/************************************************/
-
-
-/************** sign a key **************/
-signals:
-    /**
-     * Signature process result:
-     * 0 = Unknown error
-     * 1 = Bad passphrase
-     * 2 = Good passphrase
-     * 3 = Aborted by user
-     * 4 = Already signed
-     */
-    void signKeyFinished(int, const QString &, KgpgInterface*);
-
-public slots:
-    /**
-     * Key signature function
-     * @param keyid the ID of the key to be signed
-     * @param signkeyid the ID of the signing key
-     * @param local should the signature be local
-     * @param checking how careful the key was checked
-     * @param terminal if the user want to sign the key manually
-     */
-    void signKey(const QString &keyid, const QString &signkeyid, const bool local, const int checking, const bool terminal = false, const QString &uid = QString());
-
-private slots:
-    /**
-     * Read output of the signature process
-     */
-    void signKeyProcess();
-
-    /**
-     * Checks output of the signature process
-     */
-    void signKeyFin();
-
-    /**
-     * Opens the console when the user want to sign
-     * a key manually.
-     */
-    void signKeyOpenConsole();
-
-private:
-    QString m_signkey;
-    QString m_keyid;
-    int m_checking;
-    bool m_local;
-
-/****************************************/
-
-
 /************** load a photo in a QPixmap **************/
 signals:
     void loadPhotoFinished(QPixmap, KgpgInterface*);
@@ -228,8 +166,9 @@ public slots:
 
     /**
      * Key signature deletion function
-     * @param keyID QString the ID of the key
-     * @param signKeyID QString the ID of the signature key
+     * @param keyID the ID of the key
+     * @param uid the user id that is signed
+     * @param signKeyID the ID of the signature key
      */
     void KgpgDelSignature(const QString &keyID, const QString &uid, QString signKeyID);
 
