@@ -1,4 +1,4 @@
-/**
+/*
  * Copyright (C) 2002 Jean-Baptiste Mardelle <bj@altern.org>
  * Copyright (C) 2007,2008 Rolf Eike Beer <kde@opensource.sf-tec.de>
  */
@@ -133,12 +133,11 @@ KGpgTextInterfacePrivate::signFile(const KUrl &file)
 {
 	*m_process << "--command-fd=0" << "-u" << m_signID.simplified().toLocal8Bit();
 
-	for (QStringList::ConstIterator it = m_gpgopts.constBegin(); it != m_gpgopts.constEnd(); ++it)
-		*m_process << QFile::encodeName(*it);
+	*m_process << m_gpgopts;
 
 	if (m_gpgopts.contains("--detach-sign") && !m_gpgopts.contains("--output"))
-		*m_process << "--output" << QFile::encodeName(file.path() + ".sig");
-	*m_process << QFile::encodeName(file.path());
+		*m_process << "--output" << file.path() + ".sig";
+	*m_process << file.path();
 
 	m_process->start();
 }
@@ -166,8 +165,7 @@ KGpgTextInterface::encryptText(const QString &text, const QStringList &userids,
 	else
 		d->m_message = text.toUtf8();
 
-	for (QStringList::ConstIterator it = options.constBegin(); it != options.constEnd(); ++it)
-		*d->m_process << QFile::encodeName(*it);
+	*d->m_process << options;
 
 	if (userids.isEmpty()) {
 		*d->m_process << "-c";
@@ -189,9 +187,9 @@ KGpgTextInterface::encryptTextProcess()
 	QString line;
 
 	while ( (items = d->m_process->readln(line)) >= 0 ) {
-		if (line.startsWith("[GNUPG:] ")) {
+		if (line.startsWith(QLatin1String("[GNUPG:] "))) {
 			line.remove(0, 9);
-			if (line.startsWith("BEGIN_ENCRYPTION")) {
+			if (line.startsWith(QLatin1String("BEGIN_ENCRYPTION"))) {
 				d->m_process->write(d->m_message.toAscii());
 				d->m_process->closeWriteChannel();
 				d->m_message.clear();
@@ -210,14 +208,13 @@ KGpgTextInterface::encryptTextProcess()
 void
 KGpgTextInterface::encryptTextFin()
 {
-	emit txtEncryptionFinished(QString::fromUtf8(d->m_message.toAscii()).trimmed(), this);
+	emit txtEncryptionFinished(d->m_message.trimmed(), this);
 }
 
 void
 KGpgTextInterface::decryptText(const QString &text, const QStringList &options)
 {
-	for (QStringList::ConstIterator it = options.constBegin(); it != options.constEnd(); ++it)
-		*d->m_process << QFile::encodeName(*it);
+	*d->m_process << options;
 
 	*d->m_process << "-d";
 
@@ -239,6 +236,7 @@ KGpgTextInterface::decryptTextStdErr()
 		d->m_log.append(a + '\n');
 }
 
+//krazy:cond=strings
 void
 KGpgTextInterface::decryptTextStdOut()
 {
@@ -262,7 +260,7 @@ KGpgTextInterface::decryptTextStdOut()
 			} else if (line.startsWith("BEGIN_DECRYPTION")) {
 				d->m_process->closeWriteChannel();
 			} else if (line.startsWith("PLAINTEXT_LENGTH")) {
-				d->m_textlength = line.mid(line.indexOf("PLAINTEXT_LENGTH") + 16).toInt();
+				d->m_textlength = line.mid(16).toInt();
 			} else if (line.startsWith("DECRYPTION_OKAY")) {
 				d->m_ok = true;
 				// this happens if the encrypted text does not end with '\n'
@@ -299,6 +297,7 @@ KGpgTextInterface::decryptTextStdOut()
 		}
 	}
 }
+//krazy:endcond=strings
 
 void
 KGpgTextInterface::decryptTextFin()
@@ -321,8 +320,7 @@ KGpgTextInterface::signText(const QString &text, const QString &userid, const QS
 	else
 		d->m_message = text.toUtf8();
 
-	for (QStringList::ConstIterator it = options.constBegin(); it != options.constEnd(); ++it)
-		*d->m_process << QFile::encodeName(*it);
+	*d->m_process << options;
 
 	*d->m_process << "--clearsign" << "-u" << userid;
 
@@ -331,6 +329,7 @@ KGpgTextInterface::signText(const QString &text, const QString &userid, const QS
 	d->m_process->start();
 }
 
+//krazy:cond=strings
 void
 KGpgTextInterface::signTextProcess()
 {
@@ -356,6 +355,7 @@ KGpgTextInterface::signTextProcess()
 			d->m_message += line + '\n';
 	}
 }
+//krazy:endcond=strings
 
 void
 KGpgTextInterface::signTextFin()
@@ -408,11 +408,10 @@ KGpgTextInterface::encryptFile(const QStringList &encryptkeys, const KUrl &srcur
 {
 	d->m_file = srcurl;
 
-	for (QStringList::ConstIterator it = options.constBegin(); it != options.constEnd(); ++it)
-		*d->m_process << QFile::encodeName(*it);
+	*d->m_process << options;
 
 	if (!options.contains("--output"))
-		*d->m_process << "--output" << QFile::encodeName(desturl.path());
+		*d->m_process << "--output" << desturl.path();
 
 	if (!symetrical) {
 		*d->m_process << "-e";
@@ -421,7 +420,7 @@ KGpgTextInterface::encryptFile(const QStringList &encryptkeys, const KUrl &srcur
 	} else
 		*d->m_process << "-c";
 
-	*d->m_process << QFile::encodeName(srcurl.path());
+	*d->m_process << srcurl.path();
 
 	connect(d->m_process, SIGNAL(readReady(GPGProc *)), this, SLOT(fileReadEncProcess()));
 	connect(d->m_process, SIGNAL(processExited(GPGProc *)), this, SLOT(fileEncryptFin()));
@@ -436,7 +435,7 @@ KGpgTextInterface::fileReadEncProcess()
 
 	while (d->m_process->readln(line) >= 0) {
 		kDebug(2100) << line ;
-		if (line.startsWith("[GNUPG:]")) {
+		if (line.startsWith(QLatin1String("[GNUPG:]"))) {
 			if (line.contains("BEGIN_ENCRYPTION")) {
 				emit processstarted(d->m_file.path());
 			} else if (line.contains("GET_" )) {
@@ -474,10 +473,9 @@ KGpgTextInterface::KgpgDecryptFileToText(const KUrl &srcUrl, const QStringList &
 {
 	*d->m_process << "--no-batch" << "-o" << "-";
 
-	for (QStringList::ConstIterator it = options.constBegin(); it != options.constEnd(); ++it)
-		*d->m_process << QFile::encodeName(*it);
+	*d->m_process << options;
 
-	*d->m_process << "-d" << QFile::encodeName(srcUrl.path());
+	*d->m_process << "-d" << srcUrl.path();
 
 	d->m_process->setOutputChannelMode(KProcess::SeparateChannels);
 	connect(d->m_process, SIGNAL(readyReadStandardError()), this, SLOT(decryptTextStdErr()));
@@ -505,6 +503,7 @@ KGpgTextInterface::decryptFile(const KUrl &src, const KUrl &dest, const QStringL
 	d->m_process->start();
 }
 
+//krazy:cond=strings
 void
 KGpgTextInterface::decryptFileProcess()
 {
@@ -537,6 +536,7 @@ KGpgTextInterface::decryptFileProcess()
 		}
 	}
 }
+//krazy:endcond=strings
 
 void
 KGpgTextInterface::decryptFileFin(int res, QProcess::ExitStatus status)
@@ -568,14 +568,15 @@ KGpgTextInterface::KgpgVerifyFile(const KUrl &sigUrl, const KUrl &srcUrl)
 
 	*d->m_process << "--verify";
 	if (!srcUrl.isEmpty())
-		*d->m_process << QFile::encodeName(srcUrl.path());
-	*d->m_process << QFile::encodeName(sigUrl.path());
+		*d->m_process << srcUrl.path();
+	*d->m_process << sigUrl.path();
 
 	connect(d->m_process, SIGNAL(lineReadyStandardOutput()), this, SLOT(readVerify()));
 	connect(d->m_process, SIGNAL(processExited(GPGProc *)), this, SLOT(verifyfin()));
 	d->m_process->start();
 }
 
+//krazy:cond=strings
 void
 KGpgTextInterface::readVerify()
 {
@@ -611,6 +612,7 @@ KGpgTextInterface::readVerify()
 		}
 	}
 }
+//krazy:endcond=strings
 
 void
 KGpgTextInterface::verifyfin()
