@@ -1,5 +1,5 @@
 /*
- * (c) 2001 Stefan Schimanski <1Stein@gmx.de>
+ * Copyright 2001 Stefan Schimanski <1Stein@gmx.de>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -13,51 +13,47 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
-#include <qtimer.h>
-#include <qtoolbutton.h>
-#include <qgroupbox.h>
-#include <qlistview.h>
-#include <qspinbox.h>
-#include <qlineedit.h>
-#include <qcheckbox.h>
-#include <qslider.h>
-#include <qlcdnumber.h>
-#include <kurlrequester.h>
-#include <klineedit.h>
+#include "ktimer.h"
 
+#include <QProcess>
+#include <QTimer>
+
+#include <klineedit.h>
 #include <kiconloader.h>
 #include <kapplication.h>
-#include <ksystemtray.h>
 #include <kfiledialog.h>
+#include <kglobal.h>
+#include <ktoolinvocation.h>
+#include <kstandardguiitem.h>
+#include "kstatusnotifieritem.h"
 
-#include "ktimer.h"
-#include <qpushbutton.h>
-
-
-class KTimerJobItem : public QListViewItem {
+class KTimerJobItem : public QTreeWidgetItem {
 public:
-    KTimerJobItem( KTimerJob *job, QListView *parent )
-        : QListViewItem( parent ) {
+    KTimerJobItem( KTimerJob *job, QTreeWidget *parent )
+        : QTreeWidgetItem() {
+			parent->addTopLevelItem(this);
         m_job = job;
         m_error = false;
         update();
-    };
+    }
 
-    KTimerJobItem( KTimerJob *job, QListView *parent, QListViewItem *after )
-        : QListViewItem( parent, after ) {
+    KTimerJobItem( KTimerJob *job, QTreeWidget * parent, QTreeWidgetItem *after )
+        : QTreeWidgetItem() {
+			int otherItemIndex = parent->indexOfTopLevelItem(after);
+			parent->insertTopLevelItem(otherItemIndex + 1, this);
         m_job = job;
         m_error = false;
         update();
-    };
+    }
 
     virtual ~KTimerJobItem() {
         delete m_job;
-    };
+    }
 
-    KTimerJob *job() { return m_job; };
+    KTimerJob *job() { return m_job; }
 
     void setStatus( bool error ) {
         m_error = error;
@@ -68,20 +64,20 @@ public:
         setText( 0, QString::number(m_job->value()) );
 
         if( m_error )
-            setPixmap( 0, SmallIcon("stop") );
+            setIcon( 0, KIcon("process-stop") );
         else
-            setPixmap( 0, QPixmap() );
+            setIcon( 0, QPixmap() );
 
         setText( 1, QString::number(m_job->delay()) );
 
         switch( m_job->state() ) {
-            case KTimerJob::Stopped: setPixmap( 2, SmallIcon("player_stop") ); break;
-            case KTimerJob::Paused: setPixmap( 2, SmallIcon("player_pause") ); break;
-            case KTimerJob::Started: setPixmap( 2, SmallIcon("1rightarrow") ); break;
+            case KTimerJob::Stopped: setIcon( 2, KIcon("media-playback-stop") ); break;
+            case KTimerJob::Paused: setIcon( 2, KIcon("media-playback-pause") ); break;
+            case KTimerJob::Started: setIcon( 2, KIcon("arrow-right") ); break;
         }
 
         setText( 3, m_job->command() );
-    };
+    }
 
 private:
     bool m_error;
@@ -94,32 +90,36 @@ private:
 
 struct KTimerPrefPrivate
 {
-    QPtrList<KTimerJob> jobs;
+    QList<KTimerJob *> jobs;
 };
 
-KTimerPref::KTimerPref( QWidget *parent, const char *name )
-    : PrefWidget( parent, name )
+KTimerPref::KTimerPref( QWidget *parent)
+    : QDialog( parent )
 {
     d = new KTimerPrefPrivate;
 
-    d->jobs.setAutoDelete( true );
+    setupUi(this);
 
     // set icons
-    m_stop->setIconSet( SmallIconSet("player_stop") );
-    m_pause->setIconSet( SmallIconSet("player_pause") );
-    m_start->setIconSet( SmallIconSet("1rightarrow") );
+    m_stop->setIcon( KIcon("media-playback-stop") );
+    m_pause->setIcon( KIcon("media-playback-pause") );
+    m_start->setIcon( KIcon("arrow-right") );
 
     // create tray icon
-    KSystemTray *tray = new KSystemTray( this, "TimerTray" );
-    tray->show();
-    tray->setPixmap( SmallIcon( "ktimer" ) );
+    KStatusNotifierItem *tray = new KStatusNotifierItem(this);
+    tray->setIconByName("ktimer");
+    tray->setCategory(KStatusNotifierItem::ApplicationStatus);
+    tray->setStatus(KStatusNotifierItem::Active);
+    // set help button gui item
+    m_help->setGuiItem(KStandardGuiItem::help());
 
     // connect
     connect( m_add, SIGNAL(clicked()), SLOT(add()) );
     connect( m_remove, SIGNAL(clicked()), SLOT(remove()) );
-    connect( m_list, SIGNAL(currentChanged(QListViewItem*)),
-             SLOT(currentChanged(QListViewItem*)) );
-    loadJobs( kapp->config() );
+    connect( m_help, SIGNAL(clicked()), SLOT(help()) );
+    connect( m_list, SIGNAL(currentItemChanged(QTreeWidgetItem *, QTreeWidgetItem *)),
+             SLOT(currentChanged(QTreeWidgetItem *, QTreeWidgetItem *)) );
+    loadJobs( KGlobal::config().data() );
 
     show();
 }
@@ -127,19 +127,22 @@ KTimerPref::KTimerPref( QWidget *parent, const char *name )
 
 KTimerPref::~KTimerPref()
 {
-    saveJobs( kapp->config() );
     delete d;
 }
 
+void KTimerPref::saveAllJobs() {
+    saveJobs( KGlobal::config().data() );
+}
+
 
 void KTimerPref::add()
 {
     KTimerJob *job = new KTimerJob;
     KTimerJobItem *item = new KTimerJobItem( job, m_list );
 
-    connect( job, SIGNAL(delayChanged(KTimerJob*,unsigned)),
+    connect( job, SIGNAL(delayChanged(KTimerJob*,unsigned int)),
              SLOT(jobChanged(KTimerJob*)) );
-    connect( job, SIGNAL(valueChanged(KTimerJob*,unsigned)),
+    connect( job, SIGNAL(valueChanged(KTimerJob*,unsigned int)),
              SLOT(jobChanged(KTimerJob*)) );
     connect( job, SIGNAL(stateChanged(KTimerJob*,States)),
              SLOT(jobChanged(KTimerJob*)) );
@@ -151,22 +154,27 @@ void KTimerPref::add()
     job->setUser( item );
 
     // Qt drops currentChanged signals on first item (bug?)
-    if( m_list->childCount()==1 )
-      currentChanged( item );
+    if( m_list->topLevelItemCount()==1 )
+      currentChanged( item , NULL);
 
     m_list->setCurrentItem( item );
-    m_list->triggerUpdate();
+    m_list->update();
 }
 
 
 void KTimerPref::remove()
 {
     delete m_list->currentItem();
-    m_list->triggerUpdate();
+    m_list->update();
 }
 
+void KTimerPref::help()
+{
+    KToolInvocation::invokeHelp();
+}
 
-void KTimerPref::currentChanged( QListViewItem *i )
+// note, don't use old, but added it so we can connect to the new one
+void KTimerPref::currentChanged( QTreeWidgetItem *i , QTreeWidgetItem * /* old */)
 {
     KTimerJobItem *item = static_cast<KTimerJobItem*>(i);
     if( item ) {
@@ -184,6 +192,8 @@ void KTimerPref::currentChanged( QListViewItem *i )
         m_stop->disconnect();
         m_counter->disconnect();
         m_slider->disconnect();
+		m_commandLine->disconnect();
+		m_commandLine->lineEdit()->disconnect();
 
         connect( m_commandLine->lineEdit(), SIGNAL(textChanged(const QString &)),
                  job, SLOT(setCommand(const QString &)) );
@@ -207,7 +217,7 @@ void KTimerPref::currentChanged( QListViewItem *i )
         m_loop->setChecked( job->loop() );
         m_one->setChecked( job->oneInstance() );
         m_counter->display( (int)job->value() );
-        m_slider->setMaxValue( job->delay() );
+        m_slider->setMaximum( job->delay() );
         m_slider->setValue( job->value() );
 
     } else {
@@ -217,18 +227,22 @@ void KTimerPref::currentChanged( QListViewItem *i )
     }
 }
 
+const QString KTimerPref::formatSeconds( int seconds ) {
+   if(seconds<60) return QString("%1").arg(seconds);
+	return QString("%1:%2").arg( (int)seconds/60, 2, 10, QChar('0') ).arg( (int)seconds%60, 2, 10, QChar('0') ); 
+}
 
 void KTimerPref::jobChanged( KTimerJob *job )
 {
     KTimerJobItem *item = static_cast<KTimerJobItem*>(job->user());
     if( item ) {
         item->update();
-        m_list->triggerUpdate();
+        m_list->update();
 
         if( item==m_list->currentItem() ) {
 
             // XXX optimize
-            m_slider->setMaxValue( job->delay() );
+            m_slider->setMaximum( job->delay() );
             m_slider->setValue( job->value() );
             m_counter->display( (int)job->value() );
         }
@@ -240,38 +254,41 @@ void KTimerPref::jobFinished( KTimerJob *job, bool error )
 {
     KTimerJobItem *item = static_cast<KTimerJobItem*>(job->user());
     item->setStatus( error );
-    m_list->triggerUpdate();
+    m_list->update();
 }
 
+void KTimerPref::done(int result) {
+    saveAllJobs();
+    QDialog::done(result);
+}
 
 void KTimerPref::saveJobs( KConfig *cfg )
 {
-    int num = 0;
-    KTimerJobItem *item = static_cast<KTimerJobItem*>(m_list->firstChild());
-    while( item ) {
+	const int nbList=m_list->topLevelItemCount();
+	for (int num = 0; num < nbList; ++num)
+	{
+		KTimerJobItem *item = static_cast<KTimerJobItem*>(m_list->topLevelItem(num));
         item->job()->save( cfg, QString("Job%1").arg( num ) );
-        item = static_cast<KTimerJobItem*>(item->nextSibling());
-        num++;
-    }
+		
+	}
 
-    cfg->setGroup( "Jobs" );
-    cfg->writeEntry( "Number", num );
+	KConfigGroup jobscfg = cfg->group("Jobs");
+    jobscfg.writeEntry( "Number", m_list->topLevelItemCount());
 
-    cfg->sync();
+    jobscfg.sync();
 }
 
 
 void KTimerPref::loadJobs( KConfig *cfg )
 {
-    cfg->setGroup( "Jobs" );
-    int num = cfg->readNumEntry( "Number", 0 );
+    const int num = cfg->group("Jobs").readEntry( "Number", 0 );
     for( int n=0; n<num; n++ ) {
             KTimerJob *job = new KTimerJob;
             KTimerJobItem *item = new KTimerJobItem( job, m_list );
 
-            connect( job, SIGNAL(delayChanged(KTimerJob*,unsigned)),
+            connect( job, SIGNAL(delayChanged(KTimerJob*,unsigned int)),
                      SLOT(jobChanged(KTimerJob*)) );
-            connect( job, SIGNAL(valueChanged(KTimerJob*,unsigned)),
+            connect( job, SIGNAL(valueChanged(KTimerJob*,unsigned int)),
                      SLOT(jobChanged(KTimerJob*)) );
             connect( job, SIGNAL(stateChanged(KTimerJob*,States)),
                      SLOT(jobChanged(KTimerJob*)) );
@@ -283,9 +300,10 @@ void KTimerPref::loadJobs( KConfig *cfg )
             job->load( cfg, QString( "Job%1" ).arg(n) );
 
             job->setUser( item );
+            jobChanged ( job);
     }
 
-    m_list->triggerUpdate();
+    m_list->update();
 }
 
 
@@ -299,15 +317,15 @@ struct KTimerJobPrivate {
     bool oneInstance;
     unsigned value;
     KTimerJob::States state;
-    QPtrList<KProcess> processes;
+    QList<QProcess *> processes;
     void *user;
 
     QTimer *timer;
 };
 
 
-KTimerJob::KTimerJob( QObject *parent, const char *name )
-    : QObject( parent, name )
+KTimerJob::KTimerJob( QObject *parent)
+    : QObject( parent )
 {
     d = new KTimerJobPrivate;
 
@@ -316,7 +334,6 @@ KTimerJob::KTimerJob( QObject *parent, const char *name )
     d->oneInstance = true;
     d->value = 100;
     d->state = Stopped;
-    d->processes.setAutoDelete( true );
     d->user = 0;
 
     d->timer = new QTimer( this );
@@ -330,25 +347,25 @@ KTimerJob::~KTimerJob()
 }
 
 
-void KTimerJob::load( KConfig *cfg, const QString& grp )
+void KTimerJob::save( KConfig *cfg, const QString& grp )
 {
-    cfg->setGroup( grp );
-    cfg->writeEntry( "Delay", d->delay );
-    cfg->writePathEntry( "Command", d->command );
-    cfg->writeEntry( "Loop", d->loop );
-    cfg->writeEntry( "OneInstance", d->oneInstance );
-    cfg->writeEntry( "State", (int)d->state );
+	KConfigGroup groupcfg = cfg->group(grp);
+    groupcfg.writeEntry( "Delay", d->delay );
+    groupcfg.writePathEntry( "Command", d->command );
+    groupcfg.writeEntry( "Loop", d->loop );
+    groupcfg.writeEntry( "OneInstance", d->oneInstance );
+    groupcfg.writeEntry( "State", (int)d->state );
 }
 
 
-void KTimerJob::save( KConfig *cfg, const QString& grp )
+void KTimerJob::load( KConfig *cfg, const QString& grp )
 {
-    cfg->setGroup( grp );
-    setDelay( cfg->readNumEntry( "Delay", 100 ) );
-    setCommand( cfg->readPathEntry( "Command" ) );
-    setLoop( cfg->readBoolEntry( "Loop", false ) );
-    setOneInstance( cfg->readBoolEntry( "OneInstance", d->oneInstance ) );
-    setState( (States)cfg->readNumEntry( "State", (int)Stopped ) );
+	KConfigGroup groupcfg = cfg->group(grp);
+    setDelay( groupcfg.readEntry( "Delay", 100 ) );
+    setCommand( groupcfg.readPathEntry( "Command", QString() ) );
+    setLoop( groupcfg.readEntry( "Loop", false ) );
+    setOneInstance( groupcfg.readEntry( "OneInstance", d->oneInstance ) );
+    setState( (States)groupcfg.readEntry( "State", (int)Stopped ) );
 }
 
 
@@ -364,12 +381,37 @@ void KTimerJob::setUser( void *user )
 }
 
 
-unsigned KTimerJob::delay()
+unsigned KTimerJob::delay() const
 {
     return d->delay;
 }
 
 
+void KTimerJob::pause()
+{
+    setState( Paused );
+}
+
+void KTimerJob::stop()
+{
+    setState( Stopped );
+}
+
+void KTimerJob::start()
+{
+    setState( Started );
+}
+
+void KTimerJob::setDelay( int sec )
+{
+    setDelay( (unsigned)sec );
+}
+
+void KTimerJob::setValue( int value )
+{
+    setValue( (unsigned)value );
+}
+
 void KTimerJob::setDelay( unsigned sec )
 {
     if( d->delay!=sec ) {
@@ -384,7 +426,7 @@ void KTimerJob::setDelay( unsigned sec )
 }
 
 
-QString KTimerJob::command()
+QString KTimerJob::command() const
 {
     return d->command;
 }
@@ -400,7 +442,7 @@ void KTimerJob::setCommand( const QString &cmd )
 }
 
 
-bool KTimerJob::loop()
+bool KTimerJob::loop() const
 {
     return d->loop;
 }
@@ -416,7 +458,7 @@ void KTimerJob::setLoop( bool loop )
 }
 
 
-bool KTimerJob::oneInstance()
+bool KTimerJob::oneInstance() const
 {
     return d->oneInstance;
 }
@@ -432,7 +474,7 @@ void KTimerJob::setOneInstance( bool one )
 }
 
 
-unsigned KTimerJob::value()
+unsigned KTimerJob::value() const
 {
     return d->value;
 }
@@ -448,7 +490,7 @@ void KTimerJob::setValue( unsigned value )
 }
 
 
-KTimerJob::States KTimerJob::state()
+KTimerJob::States KTimerJob::state() const
 {
     return d->state;
 }
@@ -487,27 +529,36 @@ void KTimerJob::timeout()
 }
 
 
-void KTimerJob::processExited(KProcess *proc)
+void KTimerJob::processExited(int, QProcess::ExitStatus status)
 {
-    bool ok = proc->exitStatus()==0;
-    d->processes.remove( proc );
+	QProcess * proc = static_cast<QProcess*>(sender());
+    const bool ok = status==0;
+    const int i = d->processes.indexOf( proc);
+    if (i != -1)
+        delete d->processes.takeAt(i);
+
     if( !ok ) emit error( this );
     emit finished( this, !ok );
 }
 
 
+
+
 void KTimerJob::fire()
 {
     if( !d->oneInstance || d->processes.isEmpty() ) {
-        KShellProcess *proc = new KShellProcess;
-        (*proc) << d->command;
+        QProcess *proc = new QProcess;
         d->processes.append( proc );
-        connect( proc, SIGNAL(processExited(KProcess*)),
-                 SLOT(processExited(KProcess*)) );
-        bool ok = proc->start( KProcess::NotifyOnExit );
-        emit fired( this );
-        if( !ok ) {
-            d->processes.remove( proc );
+        connect( proc, SIGNAL(finished(int, QProcess::ExitStatus)),
+                 SLOT(processExited(int, QProcess::ExitStatus)) );
+        if (!d->command.simplified ().isEmpty()) {
+	        proc->start(d->command);
+	        emit fired( this );
+        }
+        if(proc->state() == QProcess::NotRunning) {
+            const int i = d->processes.indexOf( proc);
+            if (i != -1)
+                delete d->processes.takeAt(i);
             emit error( this );
             emit finished( this, true );
         }
