@@ -893,7 +893,7 @@ class JobManager(QObject, monitor.Watcher):
                     pass
 
                 self.stopped_job_prompts.add (jobid)
-                result = KMessageBox.warning(self.mainWindow, markup, i18n("Print Error"))
+                result = KMessageBox.sorry(self.mainWindow, markup, i18n("Print Error"))
                 #FIXME GTK version asks a question here but we don't have troubleshooter anyway
                 #self.print_error_dialog_response(result, jobid)
 
@@ -1132,7 +1132,7 @@ if __name__ == "__main__":
     appName     = "printer-applet"
     catalogue   = "printer-applet"
     programName = ki18n("Printer Applet")
-    version     = "1.3"
+    version     = "1.4"
     description = ki18n("Applet to view current print jobs and configure new printers")
     license     = KAboutData.License_GPL
     copyright   = ki18n("2007-2008 Canonical Ltd")
